
extensions [ matrix csv ]

breed [hives hive]

breed [bees bee]

breed [patchStatistics patchStatistic ]

bees-own
[
  destinationList
  flightPhase
  furthestDistance_m
  furthestLocationList
  knownPatchesList
  lastDestinationList
  lastLocationList
  nowDetectedPatchesList
  nTrips
  time_s

  distanceFromColony_m  ; new ***MB*** 2015-10-06 for BEESCOUT 2.0
]


patches-own
[
  flowerPatchID
  firstPatchOfFlowerpatch
  mapDisplay
  originalColor
  patchColor
  habitatTypePatch
  satelliteColor
  visits
]

patchStatistics-own
[
  areaPx
  areaSqm
  calculatedDetectionProb_per_trip
  closestDistance_m
  concentration
  detects1000List
  firstDetection_s
  maxDetectProb_per_s
  meanDistance_m
  modelledDetectionProb_per_s
  modelledDetectionProb_per_trip
  nectarGathering_s
  nNectarVisits
  nPollenVisits
  patchType
  pollenGathering_s
  quantityNectar_l
  quantityPollen_g
  startDay
  stopDay
  timeMaxDetectProb_s
  totalDetections
  visitColor

  corollaDepth_mm ; ***MB*** new for BEESCOUT 2.0
  nectarFlowerVolume_myl  ; ***MB*** new for BEESCOUT 2.0
  interFlowerTime_s   ; ***MB*** new for BEESCOUT 2.0
  flowerSpeciesList   ; ***MB*** new for BEESCOUT 2.0
  patchInfo   ; ***MB*** new for BEESCOUT 2.0, short string with additional information for the user
  proteinPollenProp   ; ***MB*** new for BEESCOUT 2.0
]


globals
[
  BackgroundColor
  BorderColor
  BottomBorder
  ColourCodeList
  ForagingFileList
  Gap_s
  LakeColor
  LeftBorder
  MaxHiveDisplAllBees_m
  MixedStratCol
  MixedStratInd
  NewTimestepForaging
  Npatches
  OutputFileList
  OutputWordResult
  PatchColoursList
  Repetitions
  RightBorder
  Scaling
  TopBorder
  TotalTrips
  WriteToFile

  ; new ***MB*** 2015-10-06 for BEESCOUT 2.0:
  HabitatDataCSV
  FlowerSpeciesList_R FlowerSpeciesList_Y FlowerSpeciesList_G FlowerSpeciesList_B FlowerSpeciesList_BR FlowerSpeciesList_T FlowerSpeciesList_V FlowerSpeciesList_M FlowerSpeciesList_P

]

;; ================================================================================================================================================================================

to Setup   ; Setup Procedure  ; RUN A PROCEDURE

  __clear-all-and-reset-ticks
 ;if RandSeed > 0 [ random-seed RandSeed ]


   ; ***MB*** new for BEESCOUT 2.0
  ifelse HighResolution = false ;
   [
     resize-world 0 300 0 210  ; min-pxcor max-pxcor min-pycor max-pycor
     set-patch-size 5
   ]
   [
     set-patch-size 1
     resize-world 0 1500 0 1050
   ]
  if AutoName = true
  [
    ifelse InputFile = "TextMap"
    [
      let name1 substring TextMap 0 (length TextMap - 4)
      set BumbleBeehaveImage_Filename (word name1 "_View.png")
      set BumbleBeehave_Inputfile (word name1 "_Patches.txt")
      if substring BumbleBeehave_Inputfile 0 9 = "BS-Map-T_"
      [
        set BumbleBeehaveImage_Filename remove "BS-Map-T_" BumbleBeehaveImage_Filename
        set BumbleBeehaveImage_Filename remove "_View" BumbleBeehaveImage_Filename
        set BumbleBeehaveImage_Filename (word "BBH-I_" BumbleBeehaveImage_Filename)
        set BumbleBeehave_Inputfile remove "BS-Map-T_" BumbleBeehave_Inputfile
        set BumbleBeehave_Inputfile remove "_Patches" BumbleBeehave_Inputfile
        set BumbleBeehave_Inputfile (word "BBH-T_" BumbleBeehave_Inputfile)
      ]
      if substring BumbleBeehave_Inputfile 0 15 = "SI_07_BS-Map-T_"
      [
        set BumbleBeehaveImage_Filename remove "SI_07_BS-Map-T_" BumbleBeehaveImage_Filename
        set BumbleBeehaveImage_Filename remove "_View" BumbleBeehaveImage_Filename
        set BumbleBeehaveImage_Filename (word "SI_07_BBH-I_" BumbleBeehaveImage_Filename)
        set BumbleBeehave_Inputfile remove "SI_07_BS-Map-T_" BumbleBeehave_Inputfile
        set BumbleBeehave_Inputfile remove "_Patches" BumbleBeehave_Inputfile
        set BumbleBeehave_Inputfile (word "SI_07_BBH-T_" BumbleBeehave_Inputfile)
      ]
    ]
    [
      let name1 substring InputFile 0 (length InputFile - 4)
      set BumbleBeehaveImage_Filename (word name1 "_View.png")
      set BumbleBeehave_Inputfile (word name1 "_Patches.txt")
    ]
  ]
  ; END  ***MB*** new for BEESCOUT 2.0

  if RandSeed != 0 [ random-seed RandSeed ]
  set OutputFileList []  ;; list, in which the results for the output file will be written
  set Gap_s 3 ; 3s: gap between 2 recordings of a bee in radar data Rothamsted - and hence also duration of a "tick" (timestep)
  set MixedStratInd false
  set MixedStratCol false

  set LakeColor cyan
  set BorderColor 125.12345678987654 ; a unique color most likely not occuring on the map (~magenta)
  set OutputWordResult ""
  create-hives 1
    [
      set color 33
      set shape "square"
      set size 4
      setxy Col_X Col_Y
    ]
  ask patches [ set pcolor BorderColor ] ; pcolor set to a unique color, to determine the borders of the map
  set PatchColoursList []
  set FlowerSpeciesList_R []
  set FlowerSpeciesList_Y []
  set FlowerSpeciesList_G []
  set FlowerSpeciesList_B []
  set FlowerSpeciesList_BR []
  set FlowerSpeciesList_T []
  set FlowerSpeciesList_V []
  set FlowerSpeciesList_M []
  set FlowerSpeciesList_P []
  if RedPatches = true [ set PatchColoursList fput red PatchColoursList ]
  if GreenPatches = true [ set PatchColoursList fput green PatchColoursList ]
  if YellowPatches = true [ set PatchColoursList fput yellow PatchColoursList ]
  if BluePatches = true [ set PatchColoursList fput Blue PatchColoursList ]
  if TurquoisePatches = true [ set PatchColoursList fput Turquoise PatchColoursList ] ; Grassland Pasture
  if VioletPatches = true [ set PatchColoursList fput Violet PatchColoursList ]; Gardens
  if BrownPatches = true [ set PatchColoursList fput Brown PatchColoursList ] ; Woodland
  if MagentaPatches = true [ set PatchColoursList fput Magenta PatchColoursList ] ; Semi-natural Scrub
  if PinkPatches = true [ set PatchColoursList fput Pink PatchColoursList ] ; Semi-natural Grassland
  set Scaling ScaleDistance_m / (Scale_X2 - Scale_X1) ;; real distance [m] divided by distance of grid points

   ifelse InputFile != "No input file"
    [
      ifelse InputFile = "TextMap"
      [
        ReadMapFromTextProc
        if count patches with [ originalColor = BorderColor ] > 0 [ DetermineBordersProc ]  ; CALL A PROCEDURE
      ]
      [
        ImportMapProc                   ;;loads the crop map    ; CALL A PROCEDURE
        if count patches with [ originalColor = BorderColor ] > 0 [ DetermineBordersProc ]  ; CALL A PROCEDURE
      ]
     ]
    [
      ask patches [   ; ELSE (if there is no input file):
                    set pcolor grey
                    set patchColor grey
                    set originalColor grey
                  ]
    ]



  if SatelliteFile != "No satellite image"
    [
      import-pcolors SatelliteFile
      ask patches [
                     set satelliteColor pcolor
                     set pcolor patchcolor
                  ]
    ]

  set WriteToFile false

  AnalyseProc   ; CALL A PROCEDURE
  ask patches [set pcolor grey ]
  ask patches with [  member? patchColor PatchColoursList = true] [ set pcolor patchColor ]
  if Lakes = true [ ask patches with [ patchColor = LakeColor ] [ set pcolor LakeColor ] ]
  if count patches with [ pcolor = LakeColor ] / (max-pxcor * max-pycor) > 0.5
    [ user-message "There are a lot of lakes on your map!" ]

end

;; ================================================================================================================================================================================

to DetermineBordersProc   ; RUN A PROCEDURE
  set TopBorder min [ pycor ] of patches with [(pycor > (max-pycor / 2)) and (originalColor = BorderColor)]      ; determine the borders of the world: top ..
  set BottomBorder max [ pycor ] of patches with [(pycor < (max-pycor / 2)) and (originalColor = BorderColor)]    ;   ...and bottom
  if TopBorder - BottomBorder <= 2
     [
       set TopBorder max-pycor + 1      ; i.e. outside the "world"
       set BottomBorder min-pycor - 1
     ]

  set RightBorder max-pxcor + 1
  if count patches with [ (pxcor > (max-pxcor / 2)) and (originalColor = BorderColor)] > 0       ; determine the borders of the world: right ..
   [ set RightBorder min [ pxcor ] of patches with [(pxcor > (max-pxcor / 2)) and (originalColor = BorderColor)] ]

  set LeftBorder min-pxcor - 1
  if count patches with [(pxcor < (max-pxcor / 2)) and (originalColor = BorderColor)] > 0
    [ set LeftBorder  max [ pxcor ] of patches with [(pxcor < (max-pxcor / 2)) and (originalColor = BorderColor)]]      ;   ...and left
  if RightBorder - LeftBorder <= 2
     [
       set RightBorder max-pxcor + 1   ; i.e. outside the "world"
       set LeftBorder min-pxcor - 1
     ]

  ask patches with [(pycor = TopBorder) or (pycor = BottomBorder) or (pxcor = LeftBorder) or (pxcor = RightBorder)]
    [ set originalColor BorderColor ]

  ask patches with [ originalColor = BorderColor ]  [ set pcolor BorderColor ]
end

;; ================================================================================================================================================================================

to ReadMapFromTextProc
 ; let colourCodeList [ brown magenta violet pink white turquoise white red yellow green ]
;let colourCodeList [ pink  white  turquoise  brown  white  white  brown  white  pink  white  pink  green  white  white  white  brown  brown  brown  brown  violet  pink  magenta  turquoise  yellow  white  red  white  white  white  white  white  ]

let nextColourType -1

file-open TextMap
let ncols read-from-string file-read-line   ; reads in number of columns
let nrows read-from-string file-read-line   ; reads in number of rows
set Scaling read-from-string file-read-line ; reads in the scaling of the map (size [m] of each grid cell)
set Scale_X1 1
set Scale_X2 ncols
set ScaleDistance_m Scaling * (Scale_X2 - Scale_X1)
set ColourCodeList read-from-string file-read-line
if ncols > max-pxcor or nrows > max-pycor [ user-message "TextMap does not match size of BEESCOUT world" ]

; ***MB*** 2016-07-21
; place map in the centre:
let leftMargin (max-pxcor - ncols) / 2
let bottomMargin (max-pycor - nrows) / 2


foreach sort patches [
  ask ?
  [
    if (pxcor >= leftMargin and pxcor < ncols + leftMargin) and (pycor >= bottomMargin and pycor < nrows + bottomMargin) and file-at-end? = false
    [
      set nextColourType file-read
      ifelse nextColourType > 0
       [
         set habitatTypePatch nextColourType
         set pcolor item (nextColourType - 1) colourCodeList
       ]

       [ set pcolor grey ]
    ]
  ]
]
file-close

ask patches
  [
    set originalColor pcolor  ;; the color of the (grid) patch in the original file
    set plabel-color black
    set flowerPatchID -1
    set patchColor pcolor  ;; saves the color after rounding
   ]

end

;; ==================================================================================
to ImportMapProc ;;loads the crop map, corrects colours    ; RUN A PROCEDURE
  import-pcolors InputFile
  ask patches
  [
    set originalColor pcolor  ;; the color of the (grid) patch in the original file
    set plabel-color black
    set flowerPatchID -1
    if remainder pcolor 10 < Black_th [ set pcolor black ]
    if remainder pcolor 10 > White_th [ set pcolor white ]
    if (pcolor > Red_min) and (pcolor <= Red_max) and (pcolor != BorderColor) [ set pcolor red ]
    if (pcolor > Yellow_min) and (pcolor <= Yellow_max) and (pcolor != BorderColor) [ set pcolor yellow ]
    if (pcolor > Green_min) and (pcolor <= Green_max) and (pcolor != BorderColor) [ set pcolor green ]
    if (pcolor > Blue_min) and (pcolor <= Blue_max) and (pcolor != BorderColor) [ set pcolor Blue ] ; Rothamsted
    if (pcolor > Turquoise_min) and (pcolor <= Turquoise_max) and (pcolor != BorderColor) [ set pcolor Turquoise ] ;Grassland Pasture
    if (pcolor > Violet_min) and (pcolor <= Violet_max) and (pcolor != BorderColor) [ set pcolor Violet ] ;Gardens
    if (pcolor > Brown_min) and (pcolor <= Brown_max) and (pcolor != BorderColor) [ set pcolor Brown ] ;Woodland
    if (pcolor > Magenta_min) and (pcolor <= Magenta_max) and (pcolor != BorderColor) [ set pcolor Magenta ] ;Semi-natural Scrub
    if (pcolor > Pink_min) and (pcolor <= Pink_max) and (pcolor != BorderColor) [ set pcolor Pink ] ;Semi-natural Grassland
    set patchColor pcolor  ;; saves the color after rounding
   ]
end

;; ================================================================================================================================================================================

to AnalyseProc  ;; determination of flower patches, calls procedures to create scout bees, and exploration of landscape   ; RUN A PROCEDURE
  clear-turtles
  let currentColor 0
  let currentPatchID -1
  let flowerPatchCounter 0
  set Repetitions round (MaxPatchRadius_m / Scaling)
    ; # of repetition depends on the scale of the landscape

  foreach sort patches
  [
    ask ?   ;; determines flowerpatches: coloured (r,b,y,g) (nlogo-)patches with ID -1 are searched, it gets a new ID and all connected (nlogo-)patches with the same colour get the same ID
    [
      if member? patchColor PatchColoursList
      [
        if flowerPatchID = -1 ;; if patch is not identified yet
        [
          set flowerPatchID (flowerPatchCounter)
          set currentColor pcolor ;; colour of the flower patch is the colour of the "firstPatchOfFlowerpatch"
          set firstPatchOfFlowerpatch true
          set currentPatchID flowerPatchID
          let search-patches patches in-radius Repetitions  ;; NEW ***VG***
          repeat Repetitions
          [
           ; ask patches  with [(pcolor = currentColor) and (flowerPatchID = currentPatchID)] ;; connected (nlogo-)patches around the firstPatchOfFlowerpatch are searched defined as part of this flower patch
           ; NEW ***VG*** NEW:
            ask search-patches with [(pcolor = currentColor) and (flowerPatchID = currentPatchID)] ;; connected (nlogo-)patches around the firstPatchOfFlowerpatch are searched defined as part of this flower patch

            [
              ask neighbors with [(pcolor = currentColor) and (flowerPatchID = -1)]
                [ set flowerPatchID currentPatchID ]
             ]
          ]
          set flowerPatchCounter flowerPatchCounter + 1
          ]
        ]
        set pcolor lime  ; to show progress of map analysis
     ]
  ]
  set Npatches currentPatchID + 1  ; as 1st patch has id 0
  CreatePatchStatisticsProc ;; creates "patchStatistics" (turtles) to store data of the flower patches   ; CALL A PROCEDURE
  create-hives 1
    [
      set color 33
      set shape "square"
      set size 4
      setxy Col_X Col_Y
    ]
  CreateBeesProc   ;; creates scouts (turtles)   ; CALL A PROCEDURE
  DetermineSizeProc                              ; CALL A PROCEDURE
  if Lakes = true
    [
      ask patches with [patchColor = black ]
        [ set patchColor LakeColor ]
    ]

  if count patchstatistics > 0
  [
    if Plot1 > count patchstatistics - 1
      or Plot2 > count patchstatistics - 1
      or Plot3 > count patchstatistics - 1
      or Plot4 > count patchstatistics - 1
      [
        set Plot1 min [ who ] of patchstatistics
        set Plot2 round ((mean [ who ] of patchstatistics + min [ who ] of patchstatistics) / 2)
        set Plot3 round ((mean [ who ] of patchstatistics + max [ who ] of patchstatistics) / 2)
        set Plot4 max [ who ] of patchstatistics
      ]
  ]

end

;; ================================================================================================================================================================================


to CreatePatchStatisticsProc  ;; "patchStatistics": turtles, containing the relevant infos of the flowerPatches, slightly different colour, located within the flowerPatch   ; RUN A PROCEDURE
let currentXcor 0
let currentYcor 0
let currentWho 0
let currentColor 0
create-PatchStatistics Npatches
     [
       set size 2
       set shape "circle"
       set currentWho Who

       ; new ***MB*** 2015-10-06 for BEESCOUT 2.0:
       set patchInfo "no info"
       set xcor mean [ pxcor ] of patches with [ flowerPatchID = currentWho ]
       set ycor mean [ pycor ] of patches with [ flowerPatchID = currentWho ]
       set currentColor patchcolor

       if currentWho != flowerPatchID
         [
           ask min-one-of patches with [ flowerPatchID = currentWho ] [distance myself]
           [
             set currentXcor pxcor
             set currentYcor pycor
             set currentColor patchcolor
           ]
           setxy currentXcor currentYcor
         ]

       set color currentColor - 1
       set label-color white
       ;if color = black [ set label-color white]
       set label who
       set modelledDetectionProb_per_s 0
       set modelledDetectionProb_per_trip 0
       set totalDetections 0
       set timeMaxDetectProb_s 0
       set detects1000List []
       set maxDetectProb_per_s 0
       set flowerSpeciesList []
       if patchColor = red
        [
          set patchType PATCHTYPE_R
          set concentration Conc_R
          set nectarGathering_s t_Nectar_R
          set pollenGathering_s t_Pollen_R
          set startDay Start_R
          set stopDay Stop_R
          set corollaDepth_mm Corolla_R   ; ***MB*** new for BEESCOUT 2.0
          set nectarFlowerVolume_myl FlowerVol_R  ; ***MB*** new for BEESCOUT 2.0
          set interFlowerTime_s intFlowerT_R      ; ***MB*** new for BEESCOUT 2.0
          set proteinPollenProp Protein_R         ; ***MB*** new for BEESCOUT 2.0

        ]
       if patchColor = Blue
        [
          set patchType PATCHTYPE_B
          set concentration Conc_B
          set nectarGathering_s t_Nectar_B
          set pollenGathering_s t_Pollen_B
          set startDay Start_B
          set stopDay Stop_B
          set corollaDepth_mm Corolla_B   ; ***MB*** new for BEESCOUT 2.0
          set nectarFlowerVolume_myl FlowerVol_B  ; ***MB*** new for BEESCOUT 2.0
          set interFlowerTime_s intFlowerT_B      ; ***MB*** new for BEESCOUT 2.0
          set flowerSpeciesList FlowerSpeciesList_B    ; ***MB*** new for BEESCOUT 2.0
          set proteinPollenProp Protein_B         ; ***MB*** new for BEESCOUT 2.0
        ]
       if patchColor = yellow
        [
          set patchType PATCHTYPE_Y
          set concentration Conc_Y
          set nectarGathering_s t_Nectar_Y
          set pollenGathering_s t_Pollen_Y
          set startDay Start_Y
          set stopDay Stop_Y
          set corollaDepth_mm Corolla_Y   ; ***MB*** new for BEESCOUT 2.0
          set nectarFlowerVolume_myl FlowerVol_Y  ; ***MB*** new for BEESCOUT 2.0
          set interFlowerTime_s intFlowerT_Y      ; ***MB*** new for BEESCOUT 2.0
          set proteinPollenProp Protein_Y         ; ***MB*** new for BEESCOUT 2.0

        ]
       if patchColor = green
        [
          set patchType PATCHTYPE_G
          set concentration Conc_G
          set nectarGathering_s t_Nectar_G
          set pollenGathering_s t_Pollen_G
          set startDay Start_G
          set stopDay Stop_G
          set corollaDepth_mm Corolla_G   ; ***MB*** new for BEESCOUT 2.0
          set nectarFlowerVolume_myl FlowerVol_G  ; ***MB*** new for BEESCOUT 2.0
          set interFlowerTime_s intFlowerT_G      ; ***MB*** new for BEESCOUT 2.0
          set flowerSpeciesList FlowerSpeciesList_G    ; ***MB*** new for BEESCOUT 2.0
          set proteinPollenProp Protein_G         ; ***MB*** new for BEESCOUT 2.0
        ]
       if patchColor = Turquoise ; Grassland Pasture
        [
          set patchType PATCHTYPE_T
          set concentration Conc_T
          set nectarGathering_s t_Nectar_T
          set pollenGathering_s t_Pollen_T
          set startDay Start_T
          set stopDay Stop_T
          set corollaDepth_mm Corolla_T   ; ***MB*** new for BEESCOUT 2.0
          set nectarFlowerVolume_myl FlowerVol_T  ; ***MB*** new for BEESCOUT 2.0
          set interFlowerTime_s intFlowerT_T      ; ***MB*** new for BEESCOUT 2.0
          set proteinPollenProp Protein_T         ; ***MB*** new for BEESCOUT 2.0

        ]
       if patchColor = Violet ;Gardens
        [
          set patchType PATCHTYPE_v
          set concentration Conc_V
          set nectarGathering_s t_Nectar_V
          set pollenGathering_s t_Pollen_V
          set startDay Start_V
          set stopDay Stop_V
          set corollaDepth_mm Corolla_V   ; ***MB*** new for BEESCOUT 2.0
          set nectarFlowerVolume_myl FlowerVol_V  ; ***MB*** new for BEESCOUT 2.0
          set interFlowerTime_s intFlowerT_V      ; ***MB*** new for BEESCOUT 2.0
          set proteinPollenProp Protein_V         ; ***MB*** new for BEESCOUT 2.0

        ]
       if patchColor = Brown ;Woodland
        [
          set patchType PATCHTYPE_BR
          set concentration Conc_BR
          set nectarGathering_s t_Nectar_BR
          set pollenGathering_s t_Pollen_BR
          set startDay Start_BR
          set stopDay Stop_BR
          set corollaDepth_mm Corolla_BR   ; ***MB*** new for BEESCOUT 2.0
          set nectarFlowerVolume_myl FlowerVol_BR  ; ***MB*** new for BEESCOUT 2.0
          set interFlowerTime_s intFlowerT_BR      ; ***MB*** new for BEESCOUT 2.0
          set proteinPollenProp Protein_BR         ; ***MB*** new for BEESCOUT 2.0

        ]
       if patchColor = Magenta ;Semi-natural Scrub
        [
          set patchType PATCHTYPE_M
          set concentration Conc_M
          set nectarGathering_s t_Nectar_M
          set pollenGathering_s t_Pollen_M
          set startDay Start_M
          set stopDay Stop_M
          set corollaDepth_mm Corolla_M   ; ***MB*** new for BEESCOUT 2.0
          set nectarFlowerVolume_myl FlowerVol_M  ; ***MB*** new for BEESCOUT 2.0
          set interFlowerTime_s intFlowerT_M      ; ***MB*** new for BEESCOUT 2.0
          set proteinPollenProp Protein_M         ; ***MB*** new for BEESCOUT 2.0

        ]
       if patchColor = Pink
        [
          set patchType PATCHTYPE_P
          set concentration Conc_P
          set nectarGathering_s t_Nectar_P
          set pollenGathering_s t_Pollen_P
          set startDay Start_P
          set stopDay Stop_P
          set corollaDepth_mm Corolla_P   ; ***MB*** new for BEESCOUT 2.0
          set nectarFlowerVolume_myl FlowerVol_P  ; ***MB*** new for BEESCOUT 2.0
          set interFlowerTime_s intFlowerT_P      ; ***MB*** new for BEESCOUT 2.0
          set proteinPollenProp Protein_P         ; ***MB*** new for BEESCOUT 2.0

        ]
     ]
end

;; ================================================================================================================================================================================

to-report CalculateDetectProbREP;; calculates the detection probability of a flower patch based on distance; see Simulation 2 in the BEESCOUT publication  ; RUN A PROCEDURE
   let lambda -0.00073 ; see BEESCOUT publication, Tab. 1, fit to "random location" search mode
   report e ^ (lambda * meanDistance_m)
end

;; ================================================================================================================================================================================


to DetermineSizeProc  ;; determines the size and distance to colony of the flower patches, writes data in short list and in output list   ; RUN A PROCEDURE
 let currentWho 0
 let shortList []
 ;;ask patchStatistics [
 foreach sort patchStatistics [ ask ? [
   if HighResolution = true [ type "Progress in DetermineSizeProc [%]: " print precision (100 * who / count patchStatistics) 1 ] ;  ; ***MB*** new for BEESCOUT 2.0

   let sumDistance 0
   let currentClosestDistanceM 999999 ;; Creation of LIST for OUTPUT file:
   set currentWho Who
   set areaPx (count patches with [flowerPatchID = currentWho])
   ask patches with [flowerPatchID = currentWho]
    [
      set sumDistance sumDistance + distancexy Col_X Col_Y
      if distancexy Col_X Col_Y < currentClosestDistanceM
         [ set currentClosestDistanceM distancexy Col_X Col_Y ]
    ]
   set areaSqm round(areaPx * Scaling * Scaling)

   if color = red - 1
        [
          set quantityNectar_l (Nectar_R / 1000) * areaSqm  ; (Nectar_R: ml)
          set quantityPollen_g Pollen_R * areaSqm
        ]
   if color = green - 1
        [
          set quantityNectar_l (Nectar_G / 1000) * areaSqm  ; (Nectar_G: ml)
          set quantityPollen_g Pollen_G * areaSqm
        ]
   if color = yellow - 1
        [
          set quantityNectar_l (Nectar_Y / 1000) * areaSqm  ; (Nectar_Y: ml)
          set quantityPollen_g Pollen_Y * areaSqm
        ]
   if color = Blue - 1
        [
          set quantityNectar_l (Nectar_B / 1000) * areaSqm  ; (Nectar_B: ml)
          set quantityPollen_g Pollen_B * areaSqm
        ]
   if color = Turquoise - 1 ; Grassland Pasture
        [
          set quantityNectar_l (Nectar_T / 1000) * areaSqm  ; (Nectar_T: ml)
          set quantityPollen_g Pollen_T * areaSqm
        ]
   if color = Violet - 1 ; Gardens
        [
          set quantityNectar_l (Nectar_V / 1000) * areaSqm  ; (Nectar_V: ml)
          set quantityPollen_g Pollen_V * areaSqm
        ]
   if color = Brown - 1 ; Woodland
        [
          set quantityNectar_l (Nectar_BR / 1000) * areaSqm  ; (Nectar_W: ml)
          set quantityPollen_g Pollen_BR * areaSqm
        ]
   if color = Magenta - 1 ; Semi-natural Scrub
        [
          set quantityNectar_l (Nectar_M / 1000) * areaSqm  ; (Nectar_M: ml)
          set quantityPollen_g Pollen_M * areaSqm
        ]
   if color = Pink - 1 ; Semi-natural Grassland
        [
          set quantityNectar_l (Nectar_P / 1000) * areaSqm  ; (Nectar_P: ml)
          set quantityPollen_g Pollen_P * areaSqm
        ]
   set meanDistance_m precision((sumDistance / areaPx) * Scaling) 1  ;; [m]
   set closestDistance_m precision (currentClosestDistanceM * Scaling) 1  ;; [m]
   if closestDistance_m < 0.1 [ set closestDistance_m 0.1 ]  ; to avoid division by 0
   set calculatedDetectionProb_per_trip CalculateDetectProbREP

   ;; Headline (added in the "WriteFromListToFileProc"):  1. who 2. xcor 3. ycor 4. patchType 5. closestDistanceM 6. areaSqm 7. modelledDetectProb
   set shortList lput Who shortList               ;; 1st column (who)
   set shortList lput xcor shortList              ;; 2nd column (xcor)
   set shortList lput ycor shortList              ;; 3rd column (ycor)
   set shortList lput patchType shortList         ;; 4th column (patchType)
   set shortList lput closestDistance_m shortList  ;; 5th column (closestDistance)
   set shortList lput areaSqm shortList           ;; 6th column (area)
   ;;                                             ;; 7th column: modelledDetectionProb - is added in the "WriteFromListToFileProc"
   set OutputFileList lput shortList OutputFileList
   set shortList []
   ] ]
end

;; ================================================================================================================================================================================

to CreateBeesProc  ;; creates scouts to explore the landscape and to determine the detection probabilities of the flower patches   ; RUN A PROCEDURE
  ask bees [ die ]
  set-current-plot "Detection Probability per trip" clear-plot
  ask patches [ set visits 0 ]
  ask patchstatistics                     ; flower pacthes have to be reset
   [
     set modelledDetectionProb_per_s 0
     set modelledDetectionProb_per_trip 0
     ;set maxDetectProb_per_s 0
     set totalDetections 0
     set firstDetection_s 0
     set detects1000List []
     set maxDetectProb_per_s 0
     set timeMaxDetectProb_s 0
   ]
  create-bees N_Bees
    [
      setxy Col_X Col_Y
      set destinationList []
      set lastDestinationList list xcor ycor ; []
      set furthestLocationList list xcor ycor
      set furthestDistance_m 0
      set lastLocationList list xcor ycor
      set shape "bee_mb_1"
      set color white    ; bees start in the "search" mode (flightPhase 2) when they first leave the hive
      set flightPhase 2
      set size 5    ; beesize
      set knownPatchesList []
      set nTrips 1 ; 0
      set nowDetectedPatchesList []
    ]
  set MixedStratInd false
  set MixedStratCol false
end

;; ================================================================================================================================================================================


to DefineHabitatsProc

ifelse file-exists? HabitatsInput
[
 set HabitatDataCSV csv:from-file HabitatsInput   ; the csv file contains information about which habitat types are represented by which colour and the relative abundance of flower species
 let headerList item 0 HabitatDataCSV   ; the header of the csv table
 let line 0

 foreach but-first HabitatDataCSV ; goes through all 'lines' (except of header) in ordered way
  [
    set line line + 1
    let currentFlowerList []
    let habitatType "none"
    let column 0
    let nameOfCurrentList first ?
    foreach but-first ? ; goes through all 'columns' of this 'line'
    [
      set column column + 1
      let content ? ; the content of a single 'cell'
      ifelse is-string? content = true ;
       [ set habitatType ? ] ; i.e. ? is a string with the habitat name
       [
         if content > 0
         [
           set content precision content 3  ; content here represents the relative abundance of a flower species in the current habitat type
           let speciesNameString (word "[" "\"" item column headerList "\"" )
           set currentFlowerList lput (word speciesNameString " " content "]") currentFlowerList

         ]
       ]
     ]

    if nameOfCurrentList = "FlowerSpeciesList_R"
       [
         set FlowerSpeciesList_R currentFlowerList
         if habitatType != "undefined" [ set Patchtype_R (word "\"" habitatType "\"") ]
       ]
    if nameOfCurrentList = "FlowerSpeciesList_Y"
      [
        set FlowerSpeciesList_Y currentFlowerList
        if habitatType != "undefined" [ set Patchtype_Y (word "\"" habitatType "\"") ]
      ]
    if nameOfCurrentList = "FlowerSpeciesList_G"
      [
        set FlowerSpeciesList_G currentFlowerList
        if habitatType != "undefined" [ set Patchtype_G (word "\"" habitatType "\"") ]
      ]
    if nameOfCurrentList = "FlowerSpeciesList_B"
      [
        if habitatType != "undefined" [ set Patchtype_B (word "\"" habitatType "\"") ]
        set FlowerSpeciesList_B currentFlowerList
      ]
    if nameOfCurrentList = "FlowerSpeciesList_BR"
      [
        set FlowerSpeciesList_BR currentFlowerList
        if habitatType != "undefined" [ set Patchtype_BR (word "\"" habitatType "\"") ]
      ]
    if nameOfCurrentList = "FlowerSpeciesList_T"
     [
       set FlowerSpeciesList_T currentFlowerList
       if habitatType != "undefined" [ set Patchtype_T (word "\"" habitatType "\"") ]
     ]
    if nameOfCurrentList = "FlowerSpeciesList_V"
     [
       set FlowerSpeciesList_V currentFlowerList
       if habitatType != "undefined" [ set Patchtype_V (word "\"" habitatType "\"") ]
     ]
    if nameOfCurrentList = "FlowerSpeciesList_M"
     [
       set FlowerSpeciesList_M currentFlowerList
       if habitatType != "undefined" [ set Patchtype_M (word "\"" habitatType "\"") ]
     ]
    if nameOfCurrentList = "FlowerSpeciesList_P"
     [
       set FlowerSpeciesList_P currentFlowerList
       if habitatType != "undefined" [ set Patchtype_P (word "\"" habitatType "\"") ]
     ]
   ]
  ]
[ ; ELSE: if file doesn't exist:

  ifelse HabitatsInput = "none"
  [
    set FlowerSpeciesList_R []
    set FlowerSpeciesList_Y []
    set FlowerSpeciesList_G []
    set FlowerSpeciesList_B []
    set FlowerSpeciesList_BR []
    set FlowerSpeciesList_T []
    set FlowerSpeciesList_V []
    set FlowerSpeciesList_M []
    set FlowerSpeciesList_P []
  ]
  [
    user-message (word "The specified HabitatsInput file cannot be loaded: " HabitatsInput)
  ]
  ]
end


;; ================================================================================================================================================================================



to Go  ;; Go Procedure movement of scouts, detection of flower patches   ; RUN A PROCEDURE
  tick
  if (ticks * Gap_s > ScoutingPeriod_hrs * 3600) or (min [ nTrips ] of bees > MaxTrips)
    [
      set OutputWordResult (word "Npatches Who areaSqm meanDistance_m modelledDetectionProb_per_s modelledDetectionProb_per_trip "  count patchStatistics)
      foreach sort patchStatistics
      [
       ask ?
        [ ; creates output for BehaviorSpace
          set OutputWordResult (word OutputWordResult " " who " " areaSqm " " meanDistance_m " " modelledDetectionProb_per_s " " modelledDetectionProb_per_trip)
        ]
      ]
      set OutputWordResult (word OutputWordResult " END")
      stop
    ]
  if remainder ticks 1000 = 0
    [  ask patchStatistics
      [ set detects1000List lput totalDetections detects1000List ]
    ]
  MoveBeesProc   ; CALL A PROCEDURE
  if count PatchStatistics > 0 [ DoDetectionPlotsProc ]   ; CALL A PROCEDURE
end



;; ================================================================================================================================================================================

to AnalyseOutfileProc     ;   (only) called by Analyse & Outfile button        ; RUN A PROCEDURE
  ; user-message ("Please wait while the button remains black. This may take a few minutes")
   Setup
   set WriteToFile true
   if is-string? NameOutfile  ;; We check to make sure we actually got a string just in case  the user hits the cancel button.
      [ if file-exists? nameOutfile   ;; If the file already exists, we begin by deleting it, otherwise new data would be appended to the old contents.
             [ file-delete nameOutfile ]
        file-open NameOutfile
       ]
   repeat ScoutingPeriod_hrs * 3600 / Gap_s
    [ Go ]
   WriteFromListToFileProc   ; CALL A PROCEDURE
   file-close
   set WriteToFile false
end


;; ================================================================================================================================================================================

to-report DisplacementREP ; [ time ]     ; RUN A PROCEDURE
let displ_m 0
 let result 0
 if BeeSpecies = "Honeybees"
   [ set displ_m 2.96 * Gap_s ]  ; 2.96 m/s times (3s) time step (derived from harmonic radar dataset Emma Wright (PhD thesis))
 if BeeSpecies = "Bumblebees"
   [ set displ_m 3.22 * Gap_s  ] ; 3.22 m/s times (3s) time step (derived from harmonic radar dataset, Osborne et al 2013)
 let displ_NLpatches displ_m / Scaling
 set result displ_NLpatches * DisplacementFactor    ; DisplacementFactor: slider (GUI), default: 1
 report result
end

;; ================================================================================================================================================================================

to-report TurningREP  ; reports rt, the angle a bee turns to its RIGHT ; RUN A PROCEDURE

 let turn 0

 if BeeSpecies = "Honeybees"
 [
   let randBar random 628 + 1 ; randomly chosen bar from the empirical turning angle histogram with a total of 628 turning angles (returns random number between [1..628]
   ; 18 bars, each 10 degrees, assuming symmetry of turning right and left  (derived from harmonic radar dataset Emma Wright (PhD thesis))

   if randBar >= 1 and randBar < 92 [ set turn 0 + random-float 10 ]
   if randBar >= 92 and randBar < 144 [ set turn 10 + random-float 10 ]
   if randBar >= 144 and randBar < 206 [ set turn 20 + random-float 10 ]
   if randBar >= 206 and randBar < 262 [ set turn 30 + random-float 10 ]
   if randBar >= 262 and randBar < 302 [ set turn 40 + random-float 10 ]
   if randBar >= 302 and randBar < 343 [ set turn 50 + random-float 10 ]
   if randBar >= 343 and randBar < 363 [ set turn 60 + random-float 10 ]
   if randBar >= 363 and randBar < 396 [ set turn 70 + random-float 10 ]
   if randBar >= 396 and randBar < 419 [ set turn 80 + random-float 10 ]
   if randBar >= 419 and randBar < 440 [ set turn 90 + random-float 10 ]
   if randBar >= 440 and randBar < 456 [ set turn 100 + random-float 10 ]
   if randBar >= 456 and randBar < 483 [ set turn 110 + random-float 10 ]
   if randBar >= 483 and randBar < 506 [ set turn 120 + random-float 10 ]
   if randBar >= 506 and randBar < 526 [ set turn 130 + random-float 10 ]
   if randBar >= 526 and randBar < 542 [ set turn 140 + random-float 10 ]
   if randBar >= 542 and randBar < 570 [ set turn 150 + random-float 10 ]
   if randBar >= 570 and randBar < 599 [ set turn 160 + random-float 10 ]
   if randBar >= 599 and randBar <= 628 [ set turn 170 + random-float 10 ]
 ]


 if BeeSpecies = "Bumblebees"
 [
   let randBar random 214 + 1 ; randomly chosen bar from the empirical turning angle histogram with a total of 214 turning angles (derived from harmonic radar dataset, Osborne et al 2013)

   if randBar >= 1 and randBar < 24 [ set turn 0 + random-float 10 ]
   if randBar >= 24 and randBar < 36 [ set turn 10 + random-float 10 ]
   if randBar >= 36 and randBar < 45 [ set turn 20 + random-float 10 ]
   if randBar >= 45 and randBar < 58 [ set turn 30 + random-float 10 ]
   if randBar >= 58 and randBar < 73 [ set turn 40 + random-float 10  ]
   if randBar >= 73 and randBar < 81 [ set turn 50 + random-float 10 ]
   if randBar >= 81 and randBar < 86 [ set turn 60 + random-float 10 ]
   if randBar >= 86 and randBar < 97 [ set turn 70 + random-float 10 ]
   if randBar >= 97 and randBar < 107 [ set turn 80 + random-float 10 ]
   if randBar >= 107 and randBar < 112 [ set turn 90 + random-float 10 ]
   if randBar >= 112 and randBar < 124 [ set turn 100 + random-float 10 ]
   if randBar >= 124 and randBar < 133 [ set turn 110 + random-float 10 ]
   if randBar >= 133 and randBar < 143 [ set turn 120 + random-float 10 ]
   if randBar >= 143 and randBar < 154 [ set turn 130 + random-float 10 ]
   if randBar >= 154 and randBar < 166 [ set turn 140 + random-float 10 ]
   if randBar >= 166 and randBar < 178 [ set turn 150 + random-float 10 ]
   if randBar >= 178 and randBar < 192 [ set turn 160 + random-float 10 ]
   if randBar >= 192 and randBar <= 214 [ set turn 170 + random-float 10 ]
 ]

 if random-float 1 > 0.5 [ set turn turn * -1 ]
 if RandomWalk = true [ set turn random-float 360 ] ; uncorrelated random walk
 set turn turn * LinearisationFactor
 if FixTurningAngle = true [ set turn FixRightTurn ]

 report turn
end

;; ================================================================================================================================================================================

to-report RelocationREP  ; defines new destination of scouts after a scouting round   ; RUN A PROCEDURE
  let result []
  if SearchMode = "colony"   ; as scouts are already at the colony and they immediately switch into search mode..
     [
       set result []    ;  .. hence destinationList remains empty!
     ]

  if SearchMode = "visited NLpatch (recruitment)" ; .. or at any location ever visited by at least one bee..
     [
       ifelse count patches with [ visits > 0 and patchColor != LakeColor ] > 0
         [
           ask one-of patches with [ visits > 0 and patchColor != LakeColor ]
            [ set result list pxcor pycor ]
         ]
         [ set result list Col_X Col_Y ]
     ]

  if SearchMode = "random location" ; .. or at any location within MaxForagingRange_m
     [
        ask one-of patches with [ patchColor != LakeColor and distancexy Col_X Col_Y * Scaling < MaxForagingRange_m and originalColor != BorderColor  ]
            [ set result list pxcor pycor ]

     ]

  if SearchMode = "known flowerpatch (individual)"  ; ..or at a flower patch, already known to that particular scout..
    [
       let memoKnownPatchesList []
       ifelse empty? knownPatchesList
         [ set result [] ]
         [
           set memoKnownPatchesList knownPatchesList
           let theChosenPatch one-of memoKnownPatchesList   ; bigger patches are more likely to be chosen
           ask one-of patches with [ flowerpatchid = theChosenPatch ]  ; (do NOT replace theChosenPatch by "one-of memoKnownPatchesList"!)
             [ set result list pxcor pycor ]
         ]
     ]

  if SearchMode = "known flowerpatch (recruitment)"   ; .. or at any one of all flower patches known to the whole colony..
    [
       let memoKnownPatchesList []
       ask patchstatistics
        [
          if totalDetections > 0  [ set memoKnownPatchesList fput who memoKnownPatchesList ]
        ]
       ifelse empty? memoKnownPatchesList
         [ set result [] ]
         [
            let theChosenPatch one-of memoKnownPatchesList              ; bigger patches are more likely to be chosen
            ask one-of patches with [ flowerpatchid = theChosenPatch ]  ; (do NOT replace theChosenPatch by "one-of memoKnownPatchesList"!)
              [ set result list pxcor pycor ]
         ]
     ]

  if SearchMode = "furthest location (individual)"  ; .. or at the furthest location this individual scout has ever been
     [ set result furthestLocationList ]

  if SearchMode = "last location (individual)"  ; .. or at the last location this individual scout has been before returning to the hive
     [ set result lastLocationList ]

  ifelse empty? result   ; new colour, depending if bees are in search mode or have a destination
    [
      set color white
      set flightPhase 2
    ]
    [
      set color green
      set flightPhase 1
    ]
  report result
end

;; ================================================================================================================================================================================

to MoveBeesProc  ; RUN A PROCEDURE
  let returningProb Gap_s / TripDuration_s ; if trip duration is randomly determined, this results in an average trip duration of TripDuration_s (only if ImmediateReturn = false)
  set TotalTrips 0
  ask bees
   [
     set time_s time_s + Gap_s               ; 3s between each recorded position in experimental radar data
     if SearchMode = "mixed strategy (individual)"
       [
         set MixedStratInd true
         set SearchMode one-of [ "colony" "known flowerpatch (individual)" "furthest location (individual)" "last location (individual)" ]
       ]

     if SearchMode = "mixed strategy (recruitment)"
       [
         set MixedStratCol true
         set SearchMode one-of [ "colony" "visited NLpatch (recruitment)" "known flowerpatch (recruitment)" "furthest location (individual)" "last location (individual)" ]
       ]

     if flightPhase = 2 [ set lastLocationList list xcor ycor ]     ; saves current location (only if bees are in search mode)

     ; if this is the END OF AN INDIVIDUAL'S SCOUTING ROUND:
     if (RandomTripDuration = false and remainder (ticks * Gap_s) (Gap_s * round (TripDuration_s / Gap_s)) = 0)   ; rounding: to make sure that trip duration can be divided by Gap_s
         or (RandomTripDuration = true and random-float 1 <= returningProb)
       [
         set destinationList list Col_x Col_y  ; then the new destination of a bee is the colony
         set color sky
         set flightPhase 3
       ]

     ; determine direction:
     ifelse destinationList = []             ; movement depends if or if not a bee has a destination
        [ TurnNoDestinationProc ]    ; CALL A PROCEDURE
        [ TurnDestinationProc ]     ; (remember: lakes do not affect bee movement, if it has a destination!)  ; CALL A PROCEDURE

     if (distancexy Col_x Col_y) * Scaling > MaxHiveDisplAllBees_m
        [ set MaxHiveDisplAllBees_m Scaling * distancexy Col_x Col_y ]  ; MaxHiveDisplAllBees_m: furthest distance of any individual from the colony ever

     if (distancexy Col_x Col_y) > DisplacementREP ; time_s    ; "visits": patches-own variable to show the distribution of bees in the landscape
        [ set visits visits + 1 ]              ; not recorded directly at the hive (i.e. within 1 Netlogo-Patch), as this would outshine visits elsewhere

     DetectionProc   ; to determine if a patch is detected   ; CALL A PROCEDURE

     if MixedStratInd = true
       [ set SearchMode "mixed strategy (individual)" ]
     if MixedStratCol = true
       [ set SearchMode "mixed strategy (recruitment)" ]

     ifelse nTrips <= MaxTrips
       [ set TotalTrips TotalTrips + nTrips ]
       [ set TotalTrips TotalTrips + (nTrips - 1) ] ; scouts are not allowed to perform more than MaxTrips trips!
    ]  ; end ask bees


 ; calculate DETECTION PROBABILITIES and save max. detect. prob. of a patch:
   ask patchStatistics
     [
       ifelse totalTrips > 0
         [
           set modelledDetectionProb_per_trip totalDetections / totalTrips
           if modelledDetectionProb_per_trip > 1 [ show "Warning! Detection Probability > 1!" ]
         ]
         [ set modelledDetectionProb_per_trip 0 ]

       set modelledDetectionProb_per_s totalDetections / (ticks * Gap_s * N_Bees)


       if modelledDetectionProb_per_s > maxDetectProb_per_s and ticks > TripDuration_s    ;  ticks > TripDuration_s: to avoid random peaks at beginning of simulation
          [
            set maxDetectProb_per_s modelledDetectionProb_per_s
            set timeMaxDetectProb_s ticks * Gap_s
          ]
     ]
   if remainder ticks 10 = 0 [ if any? patches with [ patchColor = -1 ] [ show "BUGALARM!" ask patches [ set pcolor pink ]]]

   ; actual MOVEMENT:
   ask bees with [ nTrips <= MaxTrips ] ;          when bees have finished the max. number of trips, they don't move anymore (i.e. they stay in the hive)
     [
       fd DisplacementREP ; time_s
       if (patchColor = LakeColor)                          ; LAKES & BORDERS:
         or (originalColor = BorderColor)                       ;       if a scout reaches a lake - or the borders of the world..
         or (pxcor = max-pxcor) or (pxcor = min-pxcor)
         or (pycor = max-pycor) or (pycor = min-pycor)
          [
            if flightPhase = 2 and destinationList = [] ; i.e. lakes only affect "white" bees in searching phase, not "orange" bees doing a loop
             [
               setxy item 0 lastLocationList item 1 lastLocationList   ;       .. it jumps back to its earlier position..
               set heading random-float 360                            ;       .. and chooses a new dircetion (only in searching phase!)
             ]
           ]
       set distanceFromColony_m (distancexy Col_X Col_Y) * Scaling
     ]

end


;; ================================================================================================================================================================================

to TurnDestinationProc  ; (CALLED BY INDIVIDUAL BEE) only called, if the bee has a destination   ; RUN A PROCEDURE

 facexy item 0 destinationList item 1 destinationList ; bee turns towards its destination
 if (distancexy Col_x Col_y < DisplacementREP) and (flightPhase = 2) ; if a (orange) bee loops around the colony: it retruns to ordinary search mode (white) once it reaches the colony
       [
         set destinationList []
         set color white
        ]
 if (distancexy Col_x Col_y < DisplacementREP) and (flightPhase = 3) ; if (blue) bee is back (i.e. within range of 1 step) at the colony, and flightPhase is 3 (i.e. blue, returning) (to avoid multiple relocation) their new destination is determined
       [
          let newXYlist RelocationREP
          if SearchMode = "last location (individual)" or MixedStratInd = true  or MixedStratCol = true
             [ set lastLocationList list xcor ycor ]
          set destinationList newXYlist
          set nowDetectedPatchesList [] ; a new scouting trip starts, hence list is empty
          if nTrips <= MaxTrips [ set nTrips nTrips + 1 ]
        ]

 if destinationList != []  ; only relevant, if bee has a destination (might not be the case if bees are about to leave the colony again, e.g. if SearchMode = "colony")
   [
     if (distancexy item 0 destinationList item 1 destinationList) < DisplacementREP and destinationList != list Col_x Col_y ; if this bee is at its field destination (within range of 1 step) (i.e. not at the colony)
       [
         set lastDestinationList destinationList
         set destinationList []               ; no more destination, i.e. bees switches into search behaviour
         set heading random-float 360
         set color white
         set flightPhase 2
       ]
   ]

end

;; ================================================================================================================================================================================


to TurnNoDestinationProc   ; (CALLED BY INDIVIDUAL BEE)   ; RUN A PROCEDURE
        rt TurningREP                              ; MOVEMENT if bee is in searching phase (i.e. without a destination):
        if random-float 1 <= TurnToDestinationProb
           [
            set destinationList lastDestinationList
            set color orange
           ]

        if SearchMode = "furthest location (individual)" or MixedStratInd = true or MixedStratCol = true
        [
          if (distancexy Col_X Col_Y) * Scaling > furthestDistance_m
          [
            set furthestLocationList list xcor ycor
            set furthestDistance_m (distancexy Col_X Col_Y) * Scaling
          ]
         ]

end

;; ================================================================================================================================================================================

to DetectionProc ; (CALLED BY INDIVIDUAL BEE) determines if a patch is detected   ; RUN A PROCEDURE
    ; possible DETECTION of a flower patch, if bee enters a red, blue, yellow or green NL-patch:

 if nTrips <= MaxTrips   ; patches can only dected, while MaxTrips is not exceeded!
  [
    if member? patchColor PatchColoursList  ; if a bee arrives at a patch

      [
        let patchNumber flowerPatchID
        if member? patchNumber nowDetectedPatchesList = false
        [
          set nowDetectedPatchesList fput patchNumber nowDetectedPatchesList
          ask PatchStatistic patchNumber
            [
              set totalDetections totalDetections + 1
              if firstDetection_s = 0
                [ set firstDetection_s ticks * Gap_s ]; time [s] when patch was detected for the first time
             ]
         ] ;; patch is added to the nowDetectedPatchesList if it wasn't detected earlier during this trip
        if member? patchNumber knownPatchesList = false
        [
          set knownPatchesList fput patchNumber knownPatchesList   ;; patch is added to the knownPatchesList if it wasn't detected ever
          if ImmediateReturn = true [
                                      set destinationList list Col_x Col_y
                                      set color sky
                                      set flightPhase 3
                                    ]
         ]
       ]
  ]
end

;; ================================================================================================================================================================================

to WriteFromListToFileProc   ;; called by: AnalyseProc   ; RUN A PROCEDURE
 let dayCounter 1
 let patchCounter 0
 file-print "day id oldPatchID patchType distance_m xcor ycor size_sqm quantityPollen_g concentration quantityNectar_l calculatedDetectionProb_per_trip modelledDetectionProb_per_trip nectarGathering_s pollenGathering_s "
 foreach sort patchStatistics
 [
   ask ?
   [
     if closestDistance_m <= MaxForagingRange_m
     [
       repeat 365
       [
           file-type dayCounter file-type " "                                                                ;;   1.) day
           file-type patchCounter file-type " "                                                              ;;   2.) ID (= who, if MaxForagingRange > closestDistance_m of furthest patch)
           file-type who file-type " "                                                                       ;;   3.) who = "old ID"
           file-type patchType file-type " "                                                                 ;;   4.) patchType
           file-type closestDistance_m file-type " "                                                         ;;   5.) closestDistanceM
           file-type round ((xcor - Col_X) * (ScaleDistance_m / (Scale_X2 - Scale_X1)))   file-type " "       ;;   6.) xcor relative to hive
           file-type round ((ycor - Col_Y) * (ScaleDistance_m / (Scale_X2 - Scale_X1)))  file-type " "        ;;   7.) ycor relative to hive
           file-type areaSqm file-type " "                                                                   ;;   8.) areaSqm
           ifelse dayCounter >= startDay and dayCounter <= stopDay                                           ;;   9.) quantityPollen_g
             [ file-type quantityPollen_g file-type " " ]
             [ file-type 0 file-type " " ]                                                                   ;;        ( no pollen, if patch is not in flower)
           file-type concentration file-type " "                                                             ;;   10.) concentration
           ifelse dayCounter >= startDay and dayCounter <= stopDay                                           ;;   11.) quantityNectar_l
             [ file-type quantityNectar_l file-type " " ]
             [ file-type 0 file-type " " ]                                                                   ;;        ( no nectar, if patch is not in flower)
           file-type calculatedDetectionProb_per_trip file-type " "                                          ;;   12.) calculatedDetectionProb_per_trip
           file-type modelledDetectionProb_per_trip file-type " "                                            ;;   13.) modelledDetectionProb_per_trip
           file-type nectarGathering_s file-type " "                                                         ;;   14.) nectarGathering_s
           file-type pollenGathering_s file-type " "                                                         ;;   15.) pollenGathering_s "
           file-print (" ")
           set dayCounter dayCounter + 1
           if dayCounter = 366 [ set dayCounter 1 ]
        ]
        set patchCounter patchCounter + 1
     ]
   ]
 ]
end

;; ================================================================================================================================================================================


to DoDetectionPlotsProc   ; RUN A PROCEDURE
 let detectProb1 [ modelledDetectionProb_per_trip ] of PatchStatistic Plot1
 let detectProb2 [ modelledDetectionProb_per_trip ] of PatchStatistic Plot2
 let detectProb3 [ modelledDetectionProb_per_trip ] of PatchStatistic Plot3
 let detectProb4 [ modelledDetectionProb_per_trip ] of PatchStatistic Plot4

  set-current-plot "Detection Probability per trip"
    set-current-plot-pen "plot1"
    plot (detectProb1)
    set-current-plot-pen "plot2"
    plot (detectProb2)
    set-current-plot-pen "plot3"
    plot (detectProb3)
    set-current-plot-pen "plot4"
    plot (detectProb4)
end


;; ================================================================================================================================================================================


to ReadForagingDataProc   ; RUN A PROCEDURE
   set ForagingFileList []
   file-open InputForagingFile
   let nPatchesInFile file-read
   let dustbin file-read-line  ;; to skip the headings of the txt file
   while [ not file-at-end? ] [ set ForagingFileList sentence ForagingFileList (list (list file-read file-read file-read file-read))]
   set ForagingFileList fput nPatchesInFile ForagingFileList
   file-close
   set NewTimestepForaging 1
end

;; ================================================================================================================================================================================


to ShowForagingDataProc   ; RUN A PROCEDURE
  let ForagingFileListToday []
  let nPatchesInFile item 0 ForagingFileList   ; first item (i.e. number 0) in list: # of patches, second item: first day, first patch data
  let itemNumber 1 + nPatchesInFile * (NewTimestepForaging - 1)   ; this is the first item with foraging data for today
  let itemCounter 0
  let columns length item 1 ForagingFileList ; number of data columns in the foraging input file

  repeat nPatchesInFile
   [
     set ForagingFileListToday sentence ForagingFileListToday (item (itemNumber + itemCounter) ForagingFileList)
     set itemCounter itemCounter + 1
   ]

  if item 0 ForagingFileListToday != NewTimestepForaging
    [ user-message "Error in ShowForagingDataProc - wrong day!" ]

  let currentItem 1  ; i.e. the first "who" in the list (item 0 is the day)
  let nextWho item currentItem ForagingFileListToday
  let maxItems length ForagingFileListToday

  foreach sort patchStatistics
  [
   ask ?
   [
     ifelse who = nextWho and currentItem + columns - 1 <= maxItems  ; if who is on the list and its not the end of the list yet, read data from list

     [
       set nNectarVisits item (currentItem + 1) ForagingFileListToday
       set nPollenVisits item (currentItem + 2) ForagingFileListToday
       set currentItem currentItem + columns  ; the position of the next "who" in the list
       if currentItem <= maxItems [ set nextWho item currentItem ForagingFileListToday ]

     ]
     [    ; ELSE: if patch is not on the list, it can't have had any visitors!
       set nNectarVisits 0
       set nPollenVisits 0
     ]

   ]
  ]

  ask PatchStatistics
  [
    if ForagingMap = "Nectar" [ set visitColor scale-color yellow nNectarVisits 0 MaxVisitsColour ]
    if ForagingMap = "Pollen" [ set visitColor scale-color orange nPollenVisits 0 MaxVisitsColour ]
    if ForagingMap = "All visits" [ set visitColor scale-color red (nNectarVisits + nPollenVisits) 0 MaxVisitsColour ]
    let memoWho who
    ask patches with [ flowerPatchID = memoWho ] [ set pcolor [ visitColor ] of patchStatistic memoWho ]
    if nNectarVisits + nPollenVisits > 0 and closestDistance_m > MaxForagingRange_m
      [ show "Warning! Foraging outside the max. foraging range!" ]
  ]



end

;; ================================================================================================================================================================================


to-report DateREP
  let month-names (list "January" "February" "March" "April" "May" "June" "July" "August" "September" "October" "November" "December")
  let days-in-months (list 31 28 31 30 31 30 31 31 30 31 30 31)


  let year floor (NewTimeStepForaging / 365.01) + 1
  let month 0
  let dayOfYear remainder NewTimeStepForaging 365
  if dayOfYear = 0 [ set dayOfYear 365 ]
  let dayOfMonth 0
  let sumDaysInMonths 0
  while [ sumDaysInMonths < dayOfYear ]
  [
    set month month + 1
    set sumDaysInMonths sumDaysInMonths + item (month - 1) days-in-months
    set dayOfMonth dayOfYear - sumDaysInMonths + item (month - 1) days-in-months
  ]

  report (word dayOfMonth "  " (item (month - 1) month-names) ) ; " " year )

end

;; ================================================================================================================================================================================

to BumbleBeehaveSetFlowerSpeciesProc ; updates flowerspecies in each patchtype

ask patchStatistics
[
  if patchColor = Red [ set flowerSpeciesList FlowerSpeciesList_R ]
  if patchColor = Yellow [ set flowerSpeciesList FlowerSpeciesList_Y ]
  if patchColor = Green  [ set flowerSpeciesList FlowerSpeciesList_G ]
  if patchColor = Blue  [ set flowerSpeciesList FlowerSpeciesList_B ]
  if patchColor = Brown [ set flowerSpeciesList FlowerSpeciesList_BR ]
  if patchColor = Turquoise  [ set flowerSpeciesList FlowerSpeciesList_T ]
  if patchColor = Violet [ set flowerSpeciesList FlowerSpeciesList_V ]
  if patchColor = Magenta [ set flowerSpeciesList FlowerSpeciesList_M ]
  if patchColor = Pink [ set flowerSpeciesList FlowerSpeciesList_P ]
]

end

;; ================================================================================================================================================================================



to BumbleBeehaveOutProc
 BumbleBeehaveSetFlowerSpeciesProc
 ask (turtle-set Patchstatistics bees hives) [ hide-turtle]
 export-view  BumbleBeehaveImage_Filename
 if file-exists? BumbleBeehave_Inputfile [ file-delete BumbleBeehave_Inputfile ]
 file-open BumbleBeehave_Inputfile
 file-print Scaling
 file-print count patchStatistics
 file-print "id patchType patchColour xcor ycor size_sqm quantityPollen_g proteinPollenProp quantityNectar_l concentration_mol/l startDay stopDay corollaDepth_mm nectarFlowerVolume_myl intFlowerTime_s flowerSpeciesList info"

 foreach sort patchStatistics
 [
   ask ?
   [
     file-type who file-type " "
     file-type patchType file-type " "
     file-type color + 1 file-type " "
     file-type precision xcor 3 file-type " "
     file-type precision ycor 3 file-type " "
     file-type precision areaSqm 1 file-type " "
     file-type precision quantityPollen_g 0 file-type " "
     file-type precision proteinPollenProp 3 file-type " "
     file-type precision quantityNectar_l 3 file-type " "
     file-type concentration file-type " "
     file-type startDay file-type " "
     file-type stopDay file-type " "
     file-type corollaDepth_mm file-type " "
     file-type nectarFlowerVolume_myl file-type " "
     file-type interFlowerTime_s  file-type " "
     file-type flowerSpeciesList  file-type " "

     file-write patchInfo ; printed as string i.e. with " "
     file-print (" ")
   ]
 ]
 file-close
end


;; =================================================================================================================================================================================================================

;---------------   BUTTONS   ---------------   BUTTONS   ---------------   BUTTONS   ---------------   BUTTONS   ---------------   BUTTONS   ---------------   BUTTONS   ---------------   BUTTONS   ---------------

;; =================================================================================================================================================================================================================


to Default_ButtonProc   ; "Default (Honeybees") button

;; NOT set by Default button:
  ;set  RandSeed  1
  ;set  Plot1  1
  ;set  Plot2  2
  ;set  Plot3  3
  ;set  Plot4  4

;; SET by "Default (Honeybees") button:
  set  BeeSpecies "Honeybees"
  set  Black_th  1
  set  Blue_max  110
  set  Blue_min  90
  set  BluePatches  TRUE ;White Clover
  set  TurquoisePatches  FALSE ;Grassland Pasture
  set  Turquoise_min  70
  set  Turquoise_max  80
  set  VioletPatches  FALSE ;Gardens
  set  Violet_min  110
  set  Violet_max  120
  set  BrownPatches  FALSE ;Woodland
  set  Brown_min  30
  set  Brown_max  40
  set  MagentaPatches  FALSE ;Semi-natural Scrub
  set  Magenta_min  120
  set  Magenta_max  130
  set  PinkPatches  FALSE ;Semi-natural Grassland
  set  Pink_min  130
  set  Pink_max  140
  set  BrushSize  3
  set  ByColour  0   ; 0: black
  set  Col_X   max-pxcor / 2 ; 160
  set  Col_Y  max-pycor / 2 ; 106
  set  Conc_B  1.5
  set  Conc_G  1.5
  set  Conc_R  1.5
  set  Conc_Y  1.5
  set  Conc_T  1.5 ; Turquoise- Grassland Pasture
  set  Conc_V  1.5 ; Violet- Gardens
  set  Conc_BR  1.5 ; Brown- Woodland
  set  Conc_M  1.5 ; Magenta- Semi-natural Scrub
  set  Conc_P  1.5 ; Pink- Semi-natural Grassland
  set  Day_x  1
  set  DisplacementFactor  1
  set  FixRightTurn  0.2
  set  FixTurningAngle  FALSE
  set  ForagingMap  "Nectar"
  set  Green_max  70
  set  Green_min  50
  set  GreenPatches TRUE ; false
  set  Gridsize 1000
  set  Highlight_Patch  0
  set  ImmediateReturn  FALSE
  set  InputFile "No input file"
  set  InputForagingFile  "Input_1-2_Foraging.txt"
  set  Lakes  FALSE
  set  LinearisationFactor  1
  set  MaxForagingRange_m  10000
  set  MaxPatchRadius_m  500
  set  MaxTrips 999999
  set  MaxVisitsColour  1000
  set  N_Bees  10000
  set  NameOutfile  "Input_2-1_FoodFlow.txt"
  set  Nectar_B  1
  set  Nectar_G  1
  set  Nectar_R  1
  set  Nectar_Y  1
  set  Nectar_T  1 ; Turquoise- Grassland Pasture
  set  Nectar_V  1 ; Violet- Gardens
  set  Nectar_BR  1 ; Brown- Woodland
  set  Nectar_M  1 ; Magenta- Semi-natural Scrub
  set  Nectar_P  1 ; Pink Semi-natural Grassland
  set  Patchtype_B  "\"BlueField\""
  set  Patchtype_G  "\"GreenField\""
  set  Patchtype_R  "\"RedField\""
  set  Patchtype_Y  "\"YellowField\""
  set  Patchtype_T  "\"TurquoiseField\"" ; Grassland Pasture
  set  Patchtype_V  "\"VioletField\"" ; Gardens
  set  Patchtype_BR  "\"BrownField\"" ; Woodland
  set  Patchtype_M  "\"MagentaField\"" ;Semi-natural Scrub
  set  Patchtype_P  "\"PinkField\"" ; Semi-natural Grassland
  set  Pollen_B  1
  set  Pollen_G  1
  set  Pollen_R  1
  set  Pollen_Y  1
  set  Pollen_T  1 ; Turquoise- Grassland Pasture
  set  Pollen_V  1 ; Violet- Gardens
  set  Pollen_BR  1 ; Brown- Woodlands
  set  Pollen_M  1 ; Magenta- Semi-natural Scrub
  set  Pollen_P  1 ; Pink Semi-natural Grasslands
  set  RandomTripDuration  TRUE
  set  RandomWalk  FALSE
  set  Red_max  30
  set  Red_min  10
  set  RedPatches  TRUE
  set  ReplaceColour  85   ; 85: cyan ("lake" colour)
  set  SatelliteFile  "No satellite image"
  set  Scale_X1  1
  set  Scale_X2  max-pxcor
  set  ScaleDistance_m  3000 ; average foraging distance (i.e. radius) ca. 1500m; focus on efficient patches
  set  ScoutingPeriod_hrs  9
  set  SearchMode  "known flowerpatch (recruitment)"
  set  SetColour  "Yellow"
  set  SetDirection_deg  90
  set  SetDistanceToCentre_m  250
  set  SetRadius_m  50
  set  Start_B  271
  set  Start_G  181
  set  Start_R  1
  set  Start_Y  91
  set  Start_T  0 ;Turquoise- Grassland Pasture
  set  Start_V  0 ;Violet- Gardens
  set  Start_BR 0 ;Brown- Woodlands
  set  Start_M  0 ;Magenta- Semi-natural Scrub
  set  Start_P  0 ;Pink-Semi-natural Grasslands
  set  Stop_B  360
  set  Stop_G  270
  set  Stop_R  90
  set  Stop_Y  180
  set  Stop_T  0 ;Turquoise- Grassland Pasture
  set  Stop_V  0 ;Violet- Gardens
  set  Stop_BR 0 ;Brown- Woodlands
  set  Stop_M  0 ;Magenta- Semi-natural Scrub
  set  Stop_P  0 ;Pink-Semi-natural Grasslands
  set  t_Nectar_B  1200
  set  t_Nectar_G  1200
  set  t_Nectar_R  1200
  set  t_Nectar_Y  1200
  set  t_Nectar_T  1200 ; Turquoise- Grassland Pasture
  set  t_Nectar_V  1200 ; Violet- Gradens
  set  t_Nectar_BR  1200 ;Brown- Woodland
  set  t_Nectar_M  1200 ; Magenta- Semi-natural Scrub
  set  t_Nectar_P  1200 ; Pink- Semi-natural Grassland
  set  t_Pollen_B  600
  set  t_Pollen_G  600
  set  t_Pollen_R  600
  set  t_Pollen_Y  600
  set  t_Pollen_T  600 ;Turquoise-  Grassland Pasture
  set  t_Pollen_V  600 ; Violet-Gardens
  set  t_Pollen_BR  600 ; Brown- Woodland
  set  t_Pollen_M  600 ; Magenta- semi-natural Scrub
  set  t_Pollen_P  600  ; Pinl- Semi-natural Grassland
  set  TripDuration_s  1020
  set  TurnToDestinationProb 0.02
  set  White_th  9
  set  Yellow_max  50
  set  Yellow_min  40
  set  YellowPatches  TRUE


 ; new for BEESCOUT 2.0:

  set   AutoName  TRUE
  set   BumbleBeehave_Inputfile  "No input _Patches.txt"
  set   BumbleBeehaveImage_Filename  "No input _View.png"
  set   Corolla_B  5
  set   Corolla_BR  5
  set   Corolla_G  5
  set   Corolla_M  5
  set   Corolla_P  5
  set   Corolla_R  5
  set   Corolla_T  5
  set   Corolla_V  5
  set   Corolla_Y  5
  set   FlowerVol_B  4
  set   FlowerVol_BR  4
  set   FlowerVol_G  4
  set   FlowerVol_M  4
  set   FlowerVol_P  4
  set   FlowerVol_R  4
  set   FlowerVol_T  4
  set   FlowerVol_V  4
  set   FlowerVol_Y  4
  set   HabitatsInput  "BS-Habitats_Herts.csv"
  set   HighResolution FALSE
  set   IntFlowerT_B  1.54      ; Pyke (1978): inter flower time: 1.54s, (Oecologia 34, 255-266)
  set   IntFlowerT_BR  1.54     ; Alternative values: 2.5s (Pyke 1978, Fig. 2, taking time within and between inflorescences into account, i.e. calculated as: ((1.6 * flowers per inflorescence) + ca. 3)/ flowers per inflorescence
  set   IntFlowerT_G  1.54      ; or 0.6s (Balfour et al 2013, Tab. 1)
  set   IntFlowerT_M  1.54
  set   IntFlowerT_P  1.54
  set   IntFlowerT_R  1.54
  set   IntFlowerT_T  1.54
  set   IntFlowerT_V  1.54
  set   IntFlowerT_Y  1.54
  set   Protein_B  0.2         ; Hrassnig & Crailsheim 2005: assume 20% protein in pollen, (Apidologie 36, 255–277)
  set   Protein_BR  0.2
  set   Protein_G  0.2
  set   Protein_M  0.2
  set   Protein_P  0.2
  set   Protein_R  0.2
  set   Protein_T  0.2
  set   Protein_V  0.2
  set   Protein_Y  0.2
  set   TextMap  "BS-Map-T_Suss1.txt"


end

;; ================================================================================================================================================================================

to ClearBeesProc
 if RandSeed > 0 [ random-seed RandSeed ]
 CreateBeesProc
 set MaxHiveDisplAllBees_m 0
 set TotalTrips 0
 set SCALING ScaleDistance_m / (Scale_X2 - Scale_X1)
 clear-drawing
 clear-all-plots
 clear-ticks
 RESET-TICKS
end

;; ================================================================================================================================================================================

to BumblebeesProc
 set BeeSpecies "Bumblebees"
 set SearchMode "known flowerpatch (individual)"
 set N_Bees 30
 set TripDuration_s 600
 set ScoutingPeriod_hrs 9
 set LinearisationFactor 1
 set DisplacementFactor 1
 set RandomWalk false
 set RandomTripDuration true
 set ImmediateReturn false
 set MaxTrips 999999
 set TurnToDestinationProb 0.02
end

;; ================================================================================================================================================================================

to HoneybeesProc
 set BeeSpecies "Honeybees"
 set SearchMode "known flowerpatch (recruitment)"
 set N_Bees 10000
 set TripDuration_s 1020 ; as in BEEHAVE model
 set ScoutingPeriod_hrs 9
 set LinearisationFactor 1
 set DisplacementFactor 1
 set RandomWalk false
 set RandomTripDuration true
 set ImmediateReturn false
 set MaxTrips 999999
 set TurnToDestinationProb 0.02
end


;; ===================================================================================================================================================================================================
;; ---------------      END      ---------------      END      ---------------      END      ---------------      END      ---------------      END      ---------------      END      ---------------
;; ===================================================================================================================================================================================================
@#$#@#$#@
GRAPHICS-WINDOW
3
10
1518
1096
-1
-1
5.0
1
14
1
1
1
0
0
0
1
0
300
0
210
0
0
1
ticks
30.0

BUTTON
1525
330
1687
384
Setup
Setup\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
1523
41
1684
86
InputFile
InputFile
"No input file" "TextMap" "MapImageUpdate.png" "MapImage.png" "Sussex1.png"
1

INPUTBOX
559
1317
640
1377
Col_X
184
1
0
Number

INPUTBOX
641
1317
720
1377
Col_Y
113
1
0
Number

INPUTBOX
559
1258
640
1318
Scale_X1
1
1
0
Number

INPUTBOX
641
1258
720
1318
Scale_X2
201
1
0
Number

MONITOR
560
1153
720
1198
Scaling [m/nlPatches]
SCALING
2
1
11

INPUTBOX
213
1854
367
1914
Patchtype_R
\"Crop_Field_beans\"
1
0
String

INPUTBOX
702
1854
855
1914
Patchtype_B
\"Hedgerow\"
1
0
String

INPUTBOX
376
1854
531
1914
Patchtype_Y
\"Crop_Oilseed_rape\"
1
0
String

BUTTON
1535
881
1621
914
Patches
  ;ask patches with [(patchColor = red) or (patchColor = yellow) or (patchColor = blue)] [ set pcolor patchColor ]\nask patches with [  member? patchColor PatchColoursList = true] \n  [ \n    ifelse pcolor != patchColor\n     [ set pcolor patchColor ] \n     [ set pcolor grey ]\n   ]\n  \nif Lakes = true \n[ \n  ask patches with [ patchColor = LakeColor ] \n   [\n     ifelse pcolor != LakeColor \n      [ set pcolor LakeColor ] \n      [ set pcolor grey ]\n   ]\n]\n;set satelliteView false\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1535
1052
1621
1085
Borders
ask patches with [originalColor = BorderColor]\n  [ \n    ifelse pcolor != BorderColor\n     [ set pcolor BorderColor ] \n     [ set pcolor grey ]\n   ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1692
40
1864
111
Go
\nGo\n\n
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
1129
1236
1242
1296
N_Bees
30
1
0
Number

BUTTON
1692
194
1865
227
Clear Bees
ClearBeesProc
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1535
810
1620
843
Reset
ask patchStatistics \n[ \n  show-turtle \n  set label who \n]\nask bees [ show-turtle ]\nask hives [ show-turtle ]\n\n   \nask patches [\n  set plabel \"\"\n  set pcolor gray\n   ]   \nask patches with [  member? patchColor PatchColoursList = true] [ set pcolor patchColor ]\nif Lakes = true [ ask patches with [ patchColor = LakeColor ] [ set pcolor LakeColor ] ]\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1692
160
1865
193
Step
Go
NIL
1
T
OBSERVER
NIL
S
NIL
NIL
1

INPUTBOX
559
1198
720
1258
ScaleDistance_m
5000
1
0
Number

PLOT
37
1420
438
1620
detection probability per trip
NIL
NIL
0.0
10.0
0.0
1.0E-5
true
true
"" ""
PENS
"plot1" 1.0 0 -16777216 true "" ""
"plot2" 1.0 0 -6459832 true "" ""
"plot3" 1.0 0 -10899396 true "" ""
"plot4" 1.0 0 -8630108 true "" ""

INPUTBOX
1208
1562
1258
1622
Plot1
0
1
0
Number

INPUTBOX
1260
1562
1310
1622
Plot2
0
1
0
Number

INPUTBOX
1312
1562
1362
1622
Plot3
0
1
0
Number

INPUTBOX
1364
1562
1414
1622
Plot4
0
1
0
Number

BUTTON
1535
1121
1621
1154
Pen
let penMemo true\nask one-of bees [ set penMemo pen-mode ] \nifelse penMemo = \"up\" \n  [ ask bees [pen-down]]\n  [ ask bees [pen-up]]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1623
1121
1709
1154
Erase
clear-drawing
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1623
1052
1709
1085
Satellite
\n;import-pcolors SatelliteFile\nask patches [ set pcolor satelliteColor ]\n;set satelliteView true
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1714
855
1878
888
Read foraging data
\nifelse file-exists? InputForagingFile \n[ \n  ReadForagingDataProc\n  ShowForagingDataProc\n  set NewTimestepForaging 0 ;Day\n ]\n[ user-message \"Foraging input file not found!\" ]\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
1769
1062
1881
1107
ForagingMap
ForagingMap
"Nectar" "Pollen" "All visits"
0

BUTTON
1768
923
1823
956
+1d
set NewTimeStepForaging NewTimeStepForaging + 1\nif NewTimeStepForaging > 365 [ set NewTimeStepForaging 1 ]\nShowForagingDataProc\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
1806
1017
1881
1062
time step
NewTimeStepForaging
17
1
11

BUTTON
1535
1017
1621
1050
Bees
 ask bees [ ifelse hidden? = false \n                [ hide-turtle]\n                [ show-turtle ] ]\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1714
923
1769
956
-1d
set NewTimeStepForaging NewTimeStepForaging - 1\nif NewTimeStepForaging < 1\n  [ set NewTimeStepForaging 1 ]\nShowForagingDataProc
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1823
887
1878
920
+30d
set NewTimeStepForaging NewTimeStepForaging + 30\nif NewTimeStepForaging > 365 [ set NewTimeStepForaging 1 ]\nShowForagingDataProc
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1713
888
1768
921
-30d
set NewTimeStepForaging NewTimeStepForaging - 30\nif NewTimeStepForaging < 1\n  [ set NewTimeStepForaging 1 ]\nShowForagingDataProc
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1714
956
1769
1016
Day 1
ifelse file-exists? InputForagingFile\n   [ set NewTimeStepForaging 1\n     ShowForagingDataProc ]\n     [ user-message \"No 'Input_1-3_Foraging' file found!\" ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1713
1062
1768
1107
Refresh
ifelse file-exists? InputForagingFile \n   [ ShowForagingDataProc ]\n     [ user-message \"No 'Input_1-3_Foraging' file found!\" ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
1712
1169
1881
1229
MaxVisitsColour
1000
1
0
Number

BUTTON
1782
324
1866
384
Highlight patch
ask patches with [ flowerPatchID = Highlight_Patch ] \n  [ ifelse pcolor != 95\n      [ set pcolor 95 ]\n      [ set pcolor white ]\n      \n      ]\n      \nask turtle Highlight_Patch\n[\n show-turtle\n set color color + 3\n repeat 50 [ set size size + 0.5 wait 0.02  ] \n wait 1.5\n repeat 50 [ set size size - 0.5 wait 0.02  ]\n set color color - 3\n]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
1693
324
1782
384
Highlight_Patch
0
1
0
Number

BUTTON
1822
923
1880
956
+7d
set NewTimeStepForaging NewTimeStepForaging + 7\nif NewTimeStepForaging > 365 [ set NewTimeStepForaging 1 ]\nShowForagingDataProc\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1769
888
1824
921
-7d
set NewTimeStepForaging NewTimeStepForaging - 7\nif NewTimeStepForaging < 1\n  [ set NewTimeStepForaging 1 ]\nShowForagingDataProc
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
1714
808
1878
853
InputForagingFile
InputForagingFile
"Input_1-2_Foraging.txt"
0

BUTTON
1623
880
1709
913
Labels
ask patchstatistics\n [ \n ifelse label = \"\"\n     [ \n       set label who \n       show-turtle\n     ]\n     [ set label \"\" ]\n ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
1700
1859
1854
1919
MaxPatchRadius_m
500
1
0
Number

BUTTON
1535
1086
1621
1119
Map
ask patches [ set pcolor patchColor ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
37
1263
114
1296
Import world
import-world \"3_BEEHAVE_Landscape2014_world.csv\"
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
121
1263
199
1296
Export world
export-world \"3_BEEHAVE_Landscape2014_world.csv\"
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
641
1575
730
1620
minutes passed
floor ((3 * ticks) / 60)
0
1
11

MONITOR
824
1576
975
1621
furthest distance [m]
MaxHiveDisplAllBees_m
1
1
11

CHOOSER
1524
136
1686
181
SatelliteFile
SatelliteFile
"No satellite image"
0

CHOOSER
1129
1188
1353
1233
SearchMode
SearchMode
"colony" "known flowerpatch (individual)" "known flowerpatch (recruitment)" "random location" "visited NLpatch (recruitment)" "furthest location (individual)" "last location (individual)" "mixed strategy (individual)" "mixed strategy (recruitment)"
1

INPUTBOX
1129
1297
1242
1357
TripDuration_s
600
1
0
Number

INPUTBOX
741
1215
930
1275
FixRightTurn
0.2
1
0
Number

SWITCH
741
1181
930
1214
FixTurningAngle
FixTurningAngle
1
1
-1000

INPUTBOX
1242
1236
1354
1296
RandSeed
1
1
0
Number

SLIDER
741
1145
930
1178
LinearisationFactor
LinearisationFactor
0
1
0.95
0.05
1
NIL
HORIZONTAL

SLIDER
931
1145
1121
1178
DisplacementFactor
DisplacementFactor
0
10
1
0.1
1
NIL
HORIZONTAL

BUTTON
1535
915
1621
948
Patchstats
ask Patchstatistics\n [ \n        ifelse hidden? = false \n                [ hide-turtle]\n                [ \n                  ifelse TotalDetections > 0\n                    [ show-turtle ]\n                    [ hide-turtle ]\n                  if ticks = 0 [ show-turtle ] \n                ] \n   ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
931
1181
1121
1214
RandomWalk
RandomWalk
1
1
-1000

BUTTON
1525
182
1687
229
Default (Honeybees)
Default_ButtonProc
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
1700
1762
1854
1795
Lakes
Lakes
0
1
-1000

BUTTON
1623
983
1709
1016
Distribution
let maxVisits max [ visits ] of patches\nif maxVisits > 0\n[ \n  ask patches \n    ;[ set pcolor scale-color sky Visits 0 (maxVisits / 20) ]\n    [ set pcolor scale-color sky sqrt Visits 0 sqrt (maxVisits / 10) ]\n    \n    \n ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
731
1575
821
1620
seconds passed
[time_s] of one-of bees
17
1
11

MONITOR
441
1575
553
1620
detected patches
count patchstatistics with [ totalDetections > 0]
17
1
11

BUTTON
1623
914
1709
947
Detected
ask patches [ set pcolor black ]\nask patches with [ member? patchColor PatchColoursList = true]\n;ask patches with [ patchColor = red or patchColor = blue or patchColor = yellow ]\n [\n   ifelse [ TotalDetections ] of patchstatistic flowerpatchID > 0\n     [ set pcolor patchColor ]\n     [ set pcolor grey ]\n ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1623
1087
1709
1120
Original color
ask patches [ set pcolor originalColor ]\n\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
213
1793
290
1853
Red_min
10
1
0
Number

INPUTBOX
291
1793
368
1853
Red_max
30
1
0
Number

INPUTBOX
377
1793
454
1853
Yellow_min
40
1
0
Number

INPUTBOX
454
1793
531
1853
Yellow_max
50
1
0
Number

INPUTBOX
541
1792
618
1852
Green_min
50
1
0
Number

INPUTBOX
618
1792
693
1852
Green_max
70
1
0
Number

INPUTBOX
702
1793
779
1853
Blue_min
90
1
0
Number

INPUTBOX
779
1793
856
1853
Blue_max
110
1
0
Number

INPUTBOX
1700
1797
1777
1857
Black_th
1
1
0
Number

INPUTBOX
1777
1797
1854
1857
White_th
9
1
0
Number

INPUTBOX
1242
1297
1353
1357
ScoutingPeriod_hrs
9
1
0
Number

SWITCH
932
1215
1121
1248
RandomTripDuration
RandomTripDuration
0
1
-1000

SWITCH
932
1249
1121
1282
ImmediateReturn
ImmediateReturn
1
1
-1000

PLOT
441
1421
821
1573
covered area [km^2]
NIL
NIL
0.0
10.0
0.0
0.01
true
false
"" ""
PENS
"area" 1.0 0 -16777216 true "" "plot count patches with [ visits > 0 ] * (SCALING / 1000) ^ 2"

BUTTON
1535
983
1621
1016
History
\nlet maxTime max [ firstDetection_s ] of patchStatistics\nif maxTime > 0\n[\n  ask patches with [flowerPatchID != -1] \n      [ set mapDisplay [firstDetection_s] of patchstatistic flowerPatchID ] \n  ask patches with [ flowerPatchID != -1 and mapDisplay > 0 ] \n    [ set pcolor scale-color lime sqrt mapDisplay 0 sqrt maxTime ]\n    \n]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1535
949
1621
982
model detProb
ask patches [ set pcolor gray ]\nlet maxPdetect max [ modelledDetectionProb_per_trip ] of patchStatistics\nif maxPdetect > 0\n[\n  ask patches with [flowerPatchID != -1] \n      [ set mapDisplay [modelledDetectionProb_per_trip] of patchstatistic flowerPatchID ] \n ; ask patches with [flowerPatchID != -1] [ set pcolor scale-color orange sqrt mapDisplay 0 sqrt (maxPdetect / 20)]\n  ask patches with [flowerPatchID != -1] [ set pcolor scale-color orange sqrt mapDisplay 0 0.2 ]  \n]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
214
1758
368
1791
RedPatches
RedPatches
0
1
-1000

SWITCH
541
1758
693
1791
GreenPatches
GreenPatches
0
1
-1000

SWITCH
702
1759
856
1792
BluePatches
BluePatches
0
1
-1000

SWITCH
378
1758
531
1791
YellowPatches
YellowPatches
0
1
-1000

INPUTBOX
541
1853
693
1913
Patchtype_G
\"Crop_Maize\"
1
0
String

BUTTON
37
1152
198
1197
Analyse & Outfile
AnalyseOutfileProc\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
45
1824
119
1857
Info colours
let yshift -7\nifelse ([ pcolor ] of patch 260 200 != 139)\n   and ([ pcolor ] of patch 35 80 != 51)\n[\nask patchStatistics [ hide-turtle ]\nask bees [ hide-turtle ]\nask hives [ hide-turtle ]\nask patches \n[\n set plabel \"\"\n set pcolor black\n set plabel-color black \n let x round ((pxcor / max-pxcor) * 10)\n let y round (((pycor + yshift) / max-pycor) * 14)\n set pcolor 10 * y + x\n if remainder pxcor (max-pxcor / 10) = 0\n    and remainder (pycor + yshift) (max-pycor / 14) = 0  \n    [ set plabel pcolor ] \n]\n\nuser-message \"NetLogo represents colors as a number in the range 0 to 140, with the exception of 140 itself. Black is represented by 0, 10 .. 130, white by 9.9, 19.9 ..139.9 (http://ccl.northwestern.edu/netlogo/faq.html)\"\n]\n\n; ELSE:\n[\nask patchStatistics [ show-turtle ]\nask bees [ show-turtle ]\nask hives [ show-turtle ]\nask patches [ \n              set pcolor black \n              set plabel \"\"\n             ]\nask patches with [  member? patchColor PatchColoursList = true] [ set pcolor patchColor ]\nif Lakes = true [ ask patches with [ patchColor = LakeColor ] [ set pcolor LakeColor ] ]\n\n]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
213
1916
290
1976
Start_R
153
1
0
Number

INPUTBOX
377
1916
453
1976
Start_Y
114
1
0
Number

INPUTBOX
541
1913
618
1973
Start_G
197
1
0
Number

INPUTBOX
702
1914
779
1974
Start_B
140
1
0
Number

INPUTBOX
291
1916
368
1976
Stop_R
182
1
0
Number

INPUTBOX
454
1916
531
1976
Stop_Y
136
1
0
Number

INPUTBOX
618
1913
693
1973
Stop_G
210
1
0
Number

INPUTBOX
780
1914
856
1974
Stop_B
242
1
0
Number

INPUTBOX
213
1977
289
2037
Nectar_R
0.092
1
0
Number

INPUTBOX
377
1978
454
2038
Nectar_Y
0.3
1
0
Number

INPUTBOX
541
1976
619
2036
Nectar_G
0
1
0
Number

INPUTBOX
703
1976
780
2036
Nectar_B
0.049
1
0
Number

INPUTBOX
290
1977
368
2037
Pollen_R
0.0642
1
0
Number

INPUTBOX
455
1978
531
2038
Pollen_Y
0.13
1
0
Number

INPUTBOX
621
1976
694
2036
Pollen_G
0.752
1
0
Number

INPUTBOX
781
1976
857
2036
Pollen_B
0.0094
1
0
Number

TEXTBOX
1526
397
1819
426
Artificial landscape creator:
19
0.0
1

INPUTBOX
213
2039
288
2099
t_Nectar_R
692
1
0
Number

INPUTBOX
377
2039
454
2099
t_Nectar_Y
320
1
0
Number

INPUTBOX
541
2038
619
2098
t_Nectar_G
0
1
0
Number

INPUTBOX
702
2037
780
2097
t_Nectar_B
1630
1
0
Number

INPUTBOX
289
2039
368
2099
t_Pollen_R
298
1
0
Number

INPUTBOX
455
2039
532
2099
t_Pollen_Y
221
1
0
Number

INPUTBOX
620
2038
694
2098
t_Pollen_G
600
1
0
Number

INPUTBOX
781
2037
857
2097
t_Pollen_B
2574
1
0
Number

BUTTON
540
2374
694
2407
Maize
set Patchtype_G \"\\\"Maize\\\"\"\nset Start_G 197\nset Stop_G 210\nset Nectar_G 0\nset Pollen_G 0.752\nset t_Nectar_G 0\nset t_Pollen_G 600 ; default BEEHAVE (no data available)\nset Conc_G 0\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
378
2374
456
2407
Oilseed rape
set Patchtype_Y \"\\\"Oilseed rape\\\"\"\nset Start_Y 114 \nset Stop_Y 136\nset Nectar_Y 0.3\nset Pollen_Y 0.13\nset t_Nectar_Y 320\nset t_Pollen_Y 221\nset Conc_Y 1.5\n\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
212
2373
366
2406
Field beans
set Patchtype_R \"\\\"Field beans\\\"\"\nset Start_R 153\nset Stop_R 182\nset Nectar_R 0.092 \nset Pollen_R 0.0642\nset t_Nectar_R 692\nset t_Pollen_R 298\nset Conc_R 1.28\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
701
2374
858
2407
White clover
set Patchtype_B \"\\\"White clover\\\"\"\nset Start_B 140\nset Stop_B 242\nset Nectar_B 0.049\nset Pollen_B 0.0094\nset t_Nectar_B 1630\nset t_Pollen_B 2574\nset Conc_B 1.49\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
1630
428
1767
473
SetColour
SetColour
"Red" "Yellow" "Green" "Blue" "Black" "Grey" "Brown" "Magenta" "Pink" "Turquoise" "Violet"
7

INPUTBOX
1630
474
1767
534
SetDistanceToCentre_m
250
1
0
Number

INPUTBOX
1631
570
1768
630
SetRadius_m
250
1
0
Number

BUTTON
1525
570
1630
675
Update map
set InputFile \"MapImageUpdate.png\"\nask PatchStatistics [ hide-turtle ]  ; hives, bees and patchstatistics have to be hidden, otherwise they become part of the landscape image\nask hives [ hide-turtle ]\nask bees [ hide-turtle ]\nask patches [ set plabel \"\" ]\nexport-view \"MapImageUpdate.png\" \nSetup\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1152
10
1207
43
Grid
 ask patches with [ remainder pxcor round (Gridsize / SCALING) = 0 ] [ set pcolor 124 ]\n ask patches with [ remainder pycor round (Gridsize / SCALING) = 0 ] [ set pcolor 124 ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1525
428
1629
488
Draw patches
let clickedXcor mouse-xcor\nlet clickedYcor mouse-ycor\n\nif mouse-down?\n  [ \n    ifelse BrushSize = 0\n      [ ask patch clickedXcor clickedYcor [ set pcolor read-from-string SetColour ] ]\n      [ \n        ask patches with [ (pxcor >= clickedXcor - (BrushSize / 2) and pxcor <= clickedXcor + (BrushSize / 2))\n                            and (pycor >= clickedYcor - (BrushSize / 2) and pycor <= clickedYcor + (BrushSize / 2)) ]\n                           [ set pcolor read-from-string SetColour ] \n       ]\n  ]
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
1525
489
1629
522
BrushSize
BrushSize
0
60
3
1
1
NIL
HORIZONTAL

BUTTON
1525
523
1629
569
Export map
ask PatchStatistics [ hide-turtle ]\nask hives [ hide-turtle ]\nask bees [ hide-turtle ]\nexport-view \"MapImage.png\"
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1770
428
1868
472
Clear all
ask turtles [ hide-turtle ]\nask patches [ set pcolor grey ]\nask hives [ show-turtle ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
1631
536
1767
569
SetDirection_deg
SetDirection_deg
0
360
75
5
1
°
HORIZONTAL

INPUTBOX
213
2166
288
2226
Conc_R
1.28
1
0
Number

INPUTBOX
378
2165
454
2225
Conc_Y
1.5
1
0
Number

INPUTBOX
541
2164
619
2224
Conc_G
0
1
0
Number

INPUTBOX
704
2164
782
2224
Conc_B
1.49
1
0
Number

INPUTBOX
38
1301
201
1361
MaxForagingRange_m
10000
1
0
Number

INPUTBOX
37
1201
198
1261
NameOutfile
Input_2-1_FoodFlow.txt
1
0
String

MONITOR
1632
630
1768
675
Area of patch [km^2]
(Pi * (SetRadius_m ^ 2)) / 1000000
4
1
11

BUTTON
38
1361
202
1394
Show foraging range
;ask patches [ set pcolor gray ]\nask patches with [ member? patchColor PatchColoursList = true] [ set pcolor patchColor ]\nif Lakes = true [ ask patches with [ patchColor = LakeColor ] [ set pcolor LakeColor ] ]\nask patches with [ distancexy COL_X COL_Y * Scaling > MaxForagingRange_m ] \n[ \n  let newColour (10 * (floor (pcolor / 10))) + 2\n  if newColour < 1 [ set newColour 1 ] \n  if newColour > 139 [ set newColour 139 ] \n  set pcolor newColour\n]\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1712
1108
1881
1167
Slide Show
wait 0.25\nShowForagingDataProc\nset NewTimeStepForaging NewTimeStepForaging + 1\nif NewTimeStepForaging > 365 [ set NewTimeStepForaging 1 ]
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1525
679
1630
739
Replace colour
ask patches with [ pcolor = ReplaceColour ]\n  [ set pcolor ByColour ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
1631
679
1768
739
ReplaceColour
135
1
0
Color

INPUTBOX
1770
679
1868
739
ByColour
75
1
0
Color

TEXTBOX
214
1717
505
1738
Definition food patches:
19
0.0
1

TEXTBOX
563
1117
704
1142
Scaling & hive:
19
0.0
1

BUTTON
1623
845
1709
879
Color G/B/W
\n;if [ pcolor ] of patch 50 50 != black\n; or [ pcolor ] of patch 50 50 != white\n; or [ pcolor ] of patch 50 50 != grey\n; [ set BackgroundColor black] \n\n\nif [ pcolor ] of patch 50 50 = white\n   [ set BackgroundColor grey ]\nif [ pcolor ] of patch 50 50 = black\n   [ set BackgroundColor white ] \nif [ pcolor ] of patch 50 50 = grey\n   [ set BackgroundColor black ] \n \n   \nask patches [\n  set plabel \"\"\n  set pcolor BackgroundColor\n   ]   \n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1535
846
1620
879
Grey
ask patches [\n  set plabel \"\"\n  set pcolor gray\n   ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
1535
10
1654
33
Setup map:
19
0.0
1

TEXTBOX
1699
11
1832
47
Explore map:
19
0.0
1

TEXTBOX
1132
1109
1282
1132
Search options:
19
0.0
1

TEXTBOX
1541
771
1632
794
Display:
19
0.0
1

TEXTBOX
1721
749
1867
818
Show BEEHAVE\nforaging data:
19
0.0
1

TEXTBOX
19
1111
223
1140
Create BEEHAVE outfile:
19
0.0
1

BUTTON
1623
1017
1709
1050
Hive
 ask hives [ ifelse hidden? = false \n                [ hide-turtle]\n                [ show-turtle ] ]\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1623
810
1708
843
Hide all
ask turtles [ hide-turtle]\nask patches [\n  set plabel \"\"\n  set pcolor gray\n   ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
1825
956
1880
1016
Day_x
1
1
0
Number

BUTTON
1769
956
1824
1016
Goto x
set Day_x round Day_x\nif Day_x < 1 [ set Day_x 1 ]\nwhile [ Day_x > 365 ]\n  [ set Day_x Day_x - 365 ]\nset NewTimeStepForaging Day_x\nShowForagingDataProc
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
559
1378
721
1411
Update scaling & hive
Setup\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
742
1283
931
1343
TurnToDestinationProb
0.02
1
0
Number

INPUTBOX
932
1283
1121
1343
MaxTrips
999999
1
0
Number

MONITOR
976
1576
1090
1621
min N trips
min [ nTrips ] of bees
17
1
11

MONITOR
1090
1576
1204
1621
max N trips
max [ nTrips ] of bees
17
1
11

CHOOSER
1129
1141
1353
1186
BeeSpecies
BeeSpecies
"Honeybees" "Bumblebees"
1

BUTTON
1525
264
1687
297
Bumblebees
BumblebeesProc\n\nset BeeSpecies \"Bumblebees\"\nset SearchMode \"known flowerpatch (individual)\"\nset N_Bees 30\nset TripDuration_s 600\n\nset ScoutingPeriod_hrs 9\nset LinearisationFactor 1\nset DisplacementFactor 1\nset RandomWalk false\nset RandomTripDuration true\nset ImmediateReturn false\nset MaxTrips 999999\nset TurnToDestinationProb 0.02\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1525
231
1687
264
Honeybees
HoneybeesProc
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1770
472
1868
505
Add sources
\nask patches\n[if random-float 1 < 0.01 \n   [set pcolor read-from-string SetColour] ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
823
1421
1203
1574
furthest distance [m]
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot MaxHiveDisplAllBees_m"

SLIDER
1205
10
1491
43
Gridsize
Gridsize
25
2000
1000
25
1
m
HORIZONTAL

TEXTBOX
745
1117
895
1140
Bee movement:
19
0.0
1

BUTTON
1623
948
1709
981
calc detProb
ask patches [ set pcolor gray ]\nlet maxPdetect max [ calculatedDetectionProb_per_trip ] of patchStatistics\nif maxPdetect > 0\n[\n  ask patches with [flowerPatchID != -1] \n      [ set mapDisplay [calculatedDetectionProb_per_trip] of patchstatistic flowerPatchID ] \n ; ask patches with [flowerPatchID != -1] [ set pcolor scale-color orange sqrt mapDisplay 0 sqrt (maxPdetect / 20)]\n  ask patches with [flowerPatchID != -1] [ set pcolor scale-color orange sqrt mapDisplay 0 0.2 ]  \n]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
456
2374
532
2407
Sunflower
set Patchtype_Y \"\\\"Sunflower\\\"\"\nset Start_Y 237\nset Stop_Y 264\nset Nectar_Y 0.003\nset Pollen_Y 0.108\nset t_Nectar_Y 9256\nset t_Pollen_Y 79\nset Conc_Y 1.25\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
1694
228
1844
251
My scenarios:
19
0.0
1

BUTTON
1693
255
1748
288
HB
Default_ButtonProc\nHoneybeesProc\nset Scale_X1 184\nset Scale_X2 225\nset ScaleDistance_m 3000\nset InputFile \"RealLandscape.jpg\"\nset Col_X 160\nset Col_Y 106\nset MaxPatchRadius_m 500\nset N_Bees 10000\nSetup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1804
255
1866
288
S0
;;; OUTCOMMENT this line (add a semicolon):\nuser-message \"Right click on this button and edit to setup your own, pre-defined scenario. Activate commands by deleting the semicolon before the relevant line and put a semicolon before this user-message!\"\n\n;HoneybeesProc OR BumblebeesProc ; choose either honey bees or bumble bees\n;set BluePatches true             ; if there are no blue patches, set to \"false\"!\n;set GreenPatches true            ; if there are no green patches, set to \"false\"!\n;set RedPatches true              ; if there are no red patches, set to \"false\"!\n;set YellowPatches true           ; if there are no yellow patches, set to \"false\"!\n;set Lakes false                  ; if there are lakes/obstacles patches, set to \"true\"!\n;set Scale_X1 1                   ; right click on the map to see the x-value of your first reference point\n;set Scale_X2 300                 ; right click on the map to see the x-value of your second reference point\n;set ScaleDistance_m              ; real x-distance [m] between your reference points \n;set InputFile \"MyInputFile.jpg\"  ; file name of your input map - add this also as an option to InputFile!          \n;set Col_X                        ; x-coordinate of your hive \n;set Col_Y                        ; y-coordinate of your hive\n;set MaxPatchRadius_m 500         ; approx. the max. radius a patch can have - larger areas are divided into sub-patches\n;Setup                            ; start the Setup procedure\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1693
288
1748
322
S1
;;; OUTCOMMENT this line (add a semicolon):\nuser-message \"Right click on this button and edit to setup your own, pre-defined scenario. Activate commands by deleting the semicolon before the relevant line and put a semicolon before this user-message!\"\n\n;HoneybeesProc OR BumblebeesProc ; choose either honey bees or bumble bees\n;set BluePatches true             ; if there are no blue patches, set to \"false\"!\n;set GreenPatches true            ; if there are no green patches, set to \"false\"!\n;set RedPatches true              ; if there are no red patches, set to \"false\"!\n;set YellowPatches true           ; if there are no yellow patches, set to \"false\"!\n;set Lakes false                  ; if there are lakes/obstacles patches, set to \"true\"!\n;set Scale_X1 1                   ; right click on the map to see the x-value of your first reference point\n;set Scale_X2 300                 ; right click on the map to see the x-value of your second reference point\n;set ScaleDistance_m              ; real x-distance [m] between your reference points \n;set InputFile \"MyInputFile.jpg\"  ; file name of your input map - add this also as an option to InputFile!          \n;set Col_X                        ; x-coordinate of your hive \n;set Col_Y                        ; y-coordinate of your hive\n;set MaxPatchRadius_m 500         ; approx. the max. radius a patch can have - larger areas are divided into sub-patches\n;Setup                            ; start the Setup procedure\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1749
288
1804
322
S2
;;; OUTCOMMENT this line (add a semicolon):\nuser-message \"Right click on this button and edit to setup your own, pre-defined scenario. Activate commands by deleting the semicolon before the relevant line and put a semicolon before this user-message!\"\n\n;HoneybeesProc OR BumblebeesProc ; choose either honey bees or bumble bees\n;set BluePatches true             ; if there are no blue patches, set to \"false\"!\n;set GreenPatches true            ; if there are no green patches, set to \"false\"!\n;set RedPatches true              ; if there are no red patches, set to \"false\"!\n;set YellowPatches true           ; if there are no yellow patches, set to \"false\"!\n;set Lakes false                  ; if there are lakes/obstacles patches, set to \"true\"!\n;set Scale_X1 1                   ; right click on the map to see the x-value of your first reference point\n;set Scale_X2 300                 ; right click on the map to see the x-value of your second reference point\n;set ScaleDistance_m              ; real x-distance [m] between your reference points \n;set InputFile \"MyInputFile.jpg\"  ; file name of your input map - add this also as an option to InputFile!          \n;set Col_X                        ; x-coordinate of your hive \n;set Col_Y                        ; y-coordinate of your hive\n;set MaxPatchRadius_m 500         ; approx. the max. radius a patch can have - larger areas are divided into sub-patches\n;Setup                            ; start the Setup procedure\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1749
255
1804
288
BB
Default_ButtonProc\nBumblebeesProc\nset BluePatches true\nset GreenPatches false\nset RedPatches false\nset YellowPatches false\nset Lakes true\nset Scale_X1 70\nset Scale_X2 100\nset ScaleDistance_m 100\nset InputFile \"Map_Osborne.jpg\"\nset Col_X 184\nset Col_Y 113\nset MaxPatchRadius_m 500\nSetup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1803
289
1866
322
S3
;;; OUTCOMMENT this line (add a semicolon):\nuser-message \"Right click on this button and edit to setup your own, pre-defined scenario. Activate commands by deleting the semicolon before the relevant line and put a semicolon before this user-message!\"\n\n;HoneybeesProc OR BumblebeesProc ; choose either honey bees or bumble bees\n;set BluePatches true             ; if there are no blue patches, set to \"false\"!\n;set GreenPatches true            ; if there are no green patches, set to \"false\"!\n;set RedPatches true              ; if there are no red patches, set to \"false\"!\n;set YellowPatches true           ; if there are no yellow patches, set to \"false\"!\n;set Lakes false                  ; if there are lakes/obstacles patches, set to \"true\"!\n;set Scale_X1 1                   ; right click on the map to see the x-value of your first reference point\n;set Scale_X2 300                 ; right click on the map to see the x-value of your second reference point\n;set ScaleDistance_m              ; real x-distance [m] between your reference points \n;set InputFile \"MyInputFile.jpg\"  ; file name of your input map - add this also as an option to InputFile!          \n;set Col_X                        ; x-coordinate of your hive \n;set Col_Y                        ; y-coordinate of your hive\n;set MaxPatchRadius_m 500         ; approx. the max. radius a patch can have - larger areas are divided into sub-patches\n;Setup                            ; start the Setup procedure\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1770
538
1868
629
Show
\nlet centre patch 0 0\nlet outside false\nif count hives = 0\n[\n  create-hives 1 \n    [ \n      set color 33 \n      set shape \"square\" \n      set size 4 \n      setxy Col_X Col_Y \n    ]\n]\n\n\nask one-of hives \n[ \n  ifelse patch-at-heading-and-distance SetDirection_deg (SetDistanceToCentre_m / Scaling) != nobody\n    [ set centre patch-at-heading-and-distance SetDirection_deg (SetDistanceToCentre_m / Scaling) ]\n    [ \n      user-message \"Patch outside of map!\"\n      set outside true \n    ]\n    \n]  \n\nif outside = false \n[\n\n  let centreX [ pxcor ] of centre\n  let centreY [ pycor ] of centre\n                 \n  ask patches with [distancexy centreX centreY <= (SetRadius_m / Scaling)] \n    [ \n      set pcolor read-from-string SetColour \n    ] \n]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1770
630
1868
675
Delete
\nlet centre patch 0 0\nlet outside false\nif count hives = 0\n[\n  create-hives 1 \n    [ \n      set color 33 \n      set shape \"square\" \n      set size 4 \n      setxy Col_X Col_Y \n    ]\n]\n\n\nask one-of hives \n[ \n  ifelse patch-at-heading-and-distance SetDirection_deg (SetDistanceToCentre_m / Scaling) != nobody\n    [ set centre patch-at-heading-and-distance SetDirection_deg (SetDistanceToCentre_m / Scaling) ]\n    [ \n      user-message \"Patch outside of map!\"\n      set outside true \n    ]\n    \n]  \n\nif outside = false \n[\n\n  let centreX [ pxcor ] of centre\n  let centreY [ pycor ] of centre\n                 \n  ask patches with [distancexy centreX centreY <= (SetRadius_m / Scaling)] \n    [ \n      set pcolor gray\n    ] \n]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
1713
1017
1805
1062
Date
DateREP
17
1
11

TEXTBOX
47
1764
144
1782
Switch on/off:\n
14
0.0
1

TEXTBOX
47
1798
197
1816
Colour corrections:
14
0.0
1

TEXTBOX
47
1866
123
1884
Crop type:
14
0.0
1

TEXTBOX
47
1922
206
1979
Phenology:\n(Day of year of flowering)\n
14
0.0
1

TEXTBOX
48
1987
166
2021
Nectar [ml/m^2]\n& Pollen [g/m^2]:\n
14
0.0
1

TEXTBOX
47
2053
169
2087
Handling times [s]:\n(for BEEHAVE only)
14
0.0
1

TEXTBOX
41
2190
191
2224
Concentration [mol/l]\n& inter flower time [s]:
14
0.0
1

TEXTBOX
31
2383
102
2401
Examples:
14
0.0
1

TEXTBOX
1760
408
1882
426
(requires \"Update map\")
9
0.0
1

TEXTBOX
563
1140
697
1158
(requires \"Setup\" or \"Update\")
9
0.0
1

TEXTBOX
1268
1194
1350
1212
(requires \"Setup\")
9
0.0
1

TEXTBOX
1143
1280
1242
1302
(requires \"Clear bees\")
9
0.0
1

TEXTBOX
1274
1280
1353
1298
(requires \"Setup\")
9
0.0
1

TEXTBOX
423
1726
502
1744
(requires \"Setup\")
9
0.0
1

TEXTBOX
886
1126
1036
1144
(changes applied instantly)
9
0.0
1

BUTTON
1770
505
1868
538
Add by colour
if any? patches with [ pcolor = ReplaceColour ]\n[\n ask patches with [ pcolor = ReplaceColour ]\n   [if random-float 1 < 0.01 \n       [set pcolor read-from-string SetColour] ]\n]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
1305
1243
1354
1261
(0: not set)
9
0.0
1

MONITOR
1692
113
1865
158
Progress of simulation run [%]
100 * [time_s] of one-of bees / (ScoutingPeriod_hrs * 3600)
2
1
11

MONITOR
554
1575
640
1620
hours passed
floor ((3 * ticks) / 3600)
17
1
11

SWITCH
1034
1760
1202
1793
TurquoisePatches
TurquoisePatches
0
1
-1000

SWITCH
1215
1761
1362
1794
VioletPatches
VioletPatches
1
1
-1000

SWITCH
861
1760
1021
1793
BrownPatches
BrownPatches
0
1
-1000

SWITCH
1370
1762
1532
1795
MagentaPatches
MagentaPatches
0
1
-1000

SWITCH
1538
1763
1693
1796
PinkPatches
PinkPatches
0
1
-1000

INPUTBOX
1034
1975
1118
2035
Nectar_T
1
1
0
Number

INPUTBOX
1119
1975
1204
2035
Pollen_T
1
1
0
Number

INPUTBOX
1034
1794
1116
1854
Turquoise_min
70
1
0
Number

INPUTBOX
1118
1794
1203
1854
Turquoise_max
80
1
0
Number

INPUTBOX
1035
1854
1204
1914
Patchtype_T
\"Grassland\"
1
0
String

INPUTBOX
1034
1915
1118
1975
Start_T
0
1
0
Number

INPUTBOX
1119
1915
1204
1975
Stop_T
0
1
0
Number

INPUTBOX
1037
2164
1118
2224
Conc_T
1.5
1
0
Number

INPUTBOX
1033
2038
1117
2098
t_Nectar_T
1200
1
0
Number

INPUTBOX
1118
2039
1203
2100
t_Pollen_T
600
1
0
Number

INPUTBOX
1216
1795
1279
1856
Violet_min
110
1
0
Number

INPUTBOX
1280
1795
1362
1856
Violet_max
120
1
0
Number

INPUTBOX
1216
1916
1282
1976
Start_V
0
1
0
Number

INPUTBOX
1283
1916
1362
1976
Stop_V
0
1
0
Number

INPUTBOX
1216
1856
1362
1916
Patchtype_V
\"VioletField\"
1
0
String

INPUTBOX
1216
1976
1282
2037
Nectar_V
1
1
0
Number

INPUTBOX
1283
1976
1362
2037
Pollen_V
1
1
0
Number

INPUTBOX
1217
2038
1284
2099
t_Nectar_V
1200
1
0
Number

INPUTBOX
1283
2038
1362
2098
t_Pollen_V
600
1
0
Number

INPUTBOX
1218
2162
1285
2222
Conc_V
1.5
1
0
Number

INPUTBOX
862
1792
940
1852
Brown_min
30
1
0
Number

INPUTBOX
939
1792
1021
1852
Brown_max
40
1
0
Number

INPUTBOX
862
1852
1021
1912
Patchtype_BR
\"Woodland\"
1
0
String

INPUTBOX
1371
1856
1533
1916
Patchtype_M
\"Scrub\"
1
0
String

INPUTBOX
1538
1857
1693
1917
Patchtype_P
\"Grassland\"
1
0
String

INPUTBOX
862
1912
938
1972
Start_BR
0
1
0
Number

INPUTBOX
937
1911
1022
1971
Stop_BR
0
1
0
Number

INPUTBOX
862
1971
938
2031
Nectar_BR
1
1
0
Number

INPUTBOX
937
1970
1022
2030
Pollen_BR
1
1
0
Number

INPUTBOX
861
2034
937
2094
t_Nectar_BR
1200
1
0
Number

INPUTBOX
936
2034
1021
2094
t_Pollen_BR
600
1
0
Number

INPUTBOX
863
2163
940
2223
Conc_BR
1.5
1
0
Number

INPUTBOX
1371
1796
1451
1856
Magenta_min
120
1
0
Number

INPUTBOX
1451
1796
1533
1856
Magenta_max
130
1
0
Number

INPUTBOX
1371
1917
1453
1977
Start_M
0
1
0
Number

INPUTBOX
1454
1917
1533
1977
Stop_M
0
1
0
Number

INPUTBOX
1371
1977
1453
2037
Nectar_M
1
1
0
Number

INPUTBOX
1454
1977
1533
2037
Pollen_M
1
1
0
Number

INPUTBOX
1372
2038
1453
2098
t_Nectar_M
1200
1
0
Number

INPUTBOX
1454
2038
1533
2098
t_Pollen_M
600
1
0
Number

INPUTBOX
1373
2165
1452
2225
Conc_M
1.5
1
0
Number

INPUTBOX
1538
1797
1616
1857
Pink_min
130
1
0
Number

INPUTBOX
1616
1797
1694
1857
Pink_max
140
1
0
Number

INPUTBOX
1538
1918
1600
1978
Start_P
0
1
0
Number

INPUTBOX
1604
1918
1693
1978
Stop_P
0
1
0
Number

INPUTBOX
1538
1979
1601
2039
Nectar_P
1
1
0
Number

INPUTBOX
1605
1979
1693
2039
Pollen_P
1
1
0
Number

INPUTBOX
1538
2039
1601
2099
t_Nectar_P
1200
1
0
Number

INPUTBOX
1605
2039
1693
2099
t_Pollen_P
600
1
0
Number

INPUTBOX
1537
2165
1602
2225
Conc_P
1.5
1
0
Number

BUTTON
515
1712
570
1745
0.05
;+/- 0.05 precision\n\nset red_min 14.95\nset red_max 15.05\nset yellow_min 44.95\nset yellow_max 45.05\nset green_min 54.95\nset green_max 55.05\nset blue_min 104.95\nset blue_max 105.05\n;new habitat and crop\nset brown_min 34.95\nset brown_max 35.05\nset turquoise_min 74.95\nset turquoise_max 75.05\nset violet_min 114.95\nset violet_max 115.05\nset magenta_min 124.95\nset magenta_max 125.05\nset pink_min 134.95\nset pink_max 135.05
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
574
1713
629
1746
1
;+/- 1 precision\n\nset red_min 14\nset red_max 16\nset yellow_min 44\nset yellow_max 46\nset green_min 54\nset green_max 56\nset blue_min 104\nset blue_max 106\n;new habitat and crop\nset brown_min 34\nset brown_max 36\nset turquoise_min 74\nset turquoise_max 76\nset violet_min 114\nset violet_max 116\nset magenta_min 124\nset magenta_max 126\nset pink_min 134\nset pink_max 136
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
633
1713
688
1746
5
;+/- 5 precision\nset red_min 10\nset red_max 20\nset yellow_min 40\nset yellow_max 50\nset green_min 50\nset green_max 60\nset blue_min 100\nset blue_max 110\n;new habitat and crop\nset brown_min 30\nset brown_max 40\nset turquoise_min 70\nset turquoise_max 80\nset violet_min 110\nset violet_max 120\nset magenta_min 120\nset magenta_max 130\nset pink_min 130\nset pink_max 140
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
553
1690
703
1708
Colour precision +/-
11
0.0
1

CHOOSER
1523
88
1685
133
TextMap
TextMap
"BS-Map-T_Suss1.txt"
0

TEXTBOX
237
1113
509
1141
Create Bumble-BEEHAVE files:
19
0.0
1

BUTTON
234
1152
538
1197
create Bumble-BEEHAVE files
DefineHabitatsProc\nBumbleBeehaveOutProc
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
43
2122
204
2173
Corolla depth [mm]\n& nectar volume flower [microlitre]:
14
0.0
1

INPUTBOX
213
2102
287
2162
Corolla_R
5
1
0
Number

INPUTBOX
379
2102
452
2162
Corolla_Y
5
1
0
Number

INPUTBOX
541
2100
618
2160
Corolla_G
5
1
0
Number

INPUTBOX
703
2099
780
2159
Corolla_B
5
1
0
Number

INPUTBOX
862
2098
937
2158
Corolla_BR
5
1
0
Number

INPUTBOX
1034
2101
1118
2161
Corolla_T
5
1
0
Number

INPUTBOX
1216
2100
1283
2161
Corolla_V
5
1
0
Number

INPUTBOX
1372
2101
1452
2161
Corolla_M
5
1
0
Number

INPUTBOX
1537
2098
1601
2158
Corolla_P
5
1
0
Number

INPUTBOX
234
1199
538
1259
BumbleBeehaveImage_Filename
BBH-I_Suss1.png
1
0
String

INPUTBOX
234
1259
538
1319
BumbleBeehave_Inputfile
BBH-T_Suss1.txt
1
0
String

INPUTBOX
290
2101
368
2161
FlowerVol_R
4
1
0
Number

INPUTBOX
454
2103
532
2163
FlowerVol_Y
4
1
0
Number

INPUTBOX
620
2100
695
2160
FlowerVol_G
4
1
0
Number

INPUTBOX
782
2099
858
2159
FlowerVol_B
4
1
0
Number

INPUTBOX
937
2098
1022
2158
FlowerVol_BR
4
1
0
Number

INPUTBOX
1119
2101
1204
2161
FlowerVol_T
4
1
0
Number

INPUTBOX
1283
2100
1363
2160
FlowerVol_V
4
1
0
Number

INPUTBOX
1454
2101
1533
2161
FlowerVol_M
4
1
0
Number

INPUTBOX
1604
2099
1694
2159
FlowerVol_P
4
1
0
Number

INPUTBOX
289
2166
366
2226
intFlowerT_R
1.54
1
0
Number

INPUTBOX
454
2164
532
2224
intFlowerT_Y
1.54
1
0
Number

INPUTBOX
620
2164
696
2224
intFlowerT_G
1.54
1
0
Number

INPUTBOX
784
2164
859
2224
intFlowerT_B
1.54
1
0
Number

INPUTBOX
941
2163
1025
2223
intFlowerT_BR
1.54
1
0
Number

INPUTBOX
1119
2164
1206
2224
intFlowerT_T
1.54
1
0
Number

INPUTBOX
1285
2161
1362
2221
intFlowerT_V
1.54
1
0
Number

INPUTBOX
1453
2165
1533
2225
intFlowerT_M
1.54
1
0
Number

INPUTBOX
1603
2165
1694
2225
intFlowerT_P
1.54
1
0
Number

BUTTON
1536
1156
1621
1189
Habitats
ask patches ; with [  member? patchColor PatchColoursList = true] \n  [ \n    ;ifelse pcolor != patchColor - 3 + habitatTypePatch / 7\n    ; [ set pcolor patchColor - 3 + habitatTypePatch / 7 ] ; results in a colour of the same shade, but unique for each habitat \n    \n    ifelse pcolor != 4 * habitatTypePatch\n     [ set pcolor 4 * habitatTypePatch ]\n    \n     [ set pcolor patchColor ]\n   ]\n  \nif Lakes = true \n[ \n  ask patches with [ patchColor = LakeColor ] \n   [\n     set pcolor LakeColor\n   ]\n]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
1208
1421
1413
1561
distances from hive [m]
NIL
NIL
0.0
5000.0
0.0
1000.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" "set-plot-y-range  0 10\nset-plot-pen-interval 100\nhistogram [ distanceFromColony_m ] of bees"

SWITCH
1361
1206
1522
1239
HighResolution
HighResolution
1
1
-1000

TEXTBOX
1404
1224
1518
1242
(Warning: VERY slow!)
11
0.0
1

BUTTON
1361
1142
1522
1175
translate to High Res
set HighResolution true\nset Scale_X1 Scale_X1 * 5\nset Scale_X2 Scale_X2 * 5\nset Col_X Col_X * 5\nset Col_Y Col_Y * 5\nSetup\n\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1361
1174
1522
1207
translate to Low Res
set HighResolution false\nset Scale_X1 Scale_X1 / 5\nset Scale_X2 Scale_X2 / 5\nset Col_X Col_X / 5\nset Col_Y Col_Y / 5\nSetup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
41
2319
191
2353
Flower species in \nhabitat & %cover:
14
0.0
1

MONITOR
213
2305
366
2350
NIL
FlowerSpeciesList_R
17
1
11

MONITOR
379
2305
533
2350
NIL
FlowerSpeciesList_Y
17
1
11

MONITOR
542
2305
697
2350
NIL
FlowerSpeciesList_G
17
1
11

MONITOR
704
2305
860
2350
NIL
FlowerSpeciesList_B
17
1
11

MONITOR
864
2305
1026
2350
NIL
FlowerSpeciesList_BR
17
1
11

MONITOR
1039
2305
1209
2350
NIL
FlowerSpeciesList_T
17
1
11

MONITOR
1219
2305
1364
2350
NIL
FlowerSpeciesList_V
17
1
11

MONITOR
1376
2305
1536
2350
NIL
FlowerSpeciesList_M
17
1
11

MONITOR
1540
2305
1700
2350
NIL
FlowerSpeciesList_P
17
1
11

TEXTBOX
42
2247
187
2281
Proportion protein in \npollen:
14
0.0
1

INPUTBOX
212
2236
366
2296
Protein_R
0.2
1
0
Number

INPUTBOX
377
2237
531
2297
Protein_Y
0.2
1
0
Number

INPUTBOX
540
2237
695
2297
Protein_G
0.2
1
0
Number

INPUTBOX
703
2237
860
2297
Protein_B
0.2
1
0
Number

INPUTBOX
864
2237
1027
2297
Protein_BR
0.2
1
0
Number

INPUTBOX
1036
2237
1206
2297
Protein_T
0.2
1
0
Number

INPUTBOX
1217
2236
1363
2296
Protein_V
0.2
1
0
Number

INPUTBOX
1374
2237
1535
2297
Protein_M
0.2
1
0
Number

INPUTBOX
1537
2237
1696
2297
Protein_P
0.2
1
0
Number

SWITCH
233
1321
382
1354
AutoName
AutoName
0
1
-1000

BUTTON
383
1321
539
1354
Create file names!
ifelse InputFile = \"TextMap\"\n    [\n      let name1 substring TextMap 0 (length TextMap - 4)\n      set BumbleBeehaveImage_Filename (word name1 \"_View.png\")\n      set BumbleBeehave_Inputfile (word name1 \"_Patches.txt\")    \n      if substring BumbleBeehave_Inputfile 0 9 = \"BS-Map-T_\"\n      [\n        set BumbleBeehaveImage_Filename remove \"BS-Map-T_\" BumbleBeehaveImage_Filename\n        set BumbleBeehaveImage_Filename (word \"BBH-I_\" BumbleBeehaveImage_Filename) \n        set BumbleBeehave_Inputfile remove \"BS-Map-T_\" BumbleBeehave_Inputfile\n        set BumbleBeehave_Inputfile (word \"BBH-T_\" BumbleBeehave_Inputfile)         \n      ] \n    ]\n    [\n      let name1 substring InputFile 0 (length InputFile - 4)\n      set BumbleBeehaveImage_Filename (word name1 \"_View.png\")\n      set BumbleBeehave_Inputfile (word name1 \"_Patches.txt\")\n    ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
1701
1995
1856
2055
HabitatsInput
BS-Habitats_Herts.csv
1
0
String

BUTTON
1701
1928
1855
1994
NIL
DefineHabitatsProc
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
1366
1106
1524
1129
Resolution:
19
0.0
1

BUTTON
1525
297
1687
330
Bumble-BEEHAVE Example
Default_ButtonProc\nset  BeeSpecies  \"Bumblebees\"\nset  BrownPatches  TRUE\nset  ByColour  75\nset  Col_X  184\nset  Col_Y  113\nset  Conc_B  1.49\nset  Conc_G  0\nset  Conc_R  1.28\nset  InputFile  \"TextMap\"\nset  Lakes  TRUE\nset  LinearisationFactor  0.95\nset  MagentaPatches  TRUE\nset  N_Bees  30\nset  Nectar_B  0.049\nset  Nectar_G  0\nset  Nectar_R  0.092\nset  Nectar_Y  0.3\nset  Patchtype_B  \"\\\"Hedgerow\\\"\"\nset  Patchtype_BR  \"\\\"Woodland\\\"\"\nset  Patchtype_G  \"\\\"Crop_Maize\\\"\"\nset  Patchtype_M  \"\\\"Scrub\\\"\"\nset  Patchtype_P  \"\\\"Grassland\\\"\"\nset  Patchtype_R  \"\\\"Crop_Field_beans\\\"\"\nset  Patchtype_T  \"\\\"Grassland\\\"\"\nset  Patchtype_Y  \"\\\"Crop_Oilseed_rape\\\"\"\nset  PinkPatches  TRUE\nset  Pollen_B  0.0094\nset  Pollen_G  0.752\nset  Pollen_R  0.0642\nset  Pollen_Y  0.13\nset  RandSeed  1\nset  ReplaceColour  135\nset  Scale_X2  202\nset  ScaleDistance_m  5025\nset  SearchMode  \"known flowerpatch (individual)\"\nset  SetColour  \"Magenta\"\nset  SetDirection_deg  75\nset  SetRadius_m  250\nset  Start_B  140\nset  Start_G  197\nset  Start_R  153\nset  Start_Y  114\nset  Stop_B  242\nset  Stop_G  210\nset  Stop_R  182\nset  Stop_Y  136\nset  t_Nectar_B  1630\nset  t_Nectar_G  0\nset  t_Nectar_R  692\nset  t_Nectar_Y  320\nset  t_Pollen_B  2574\nset  t_Pollen_R  298\nset  t_Pollen_Y  221\nset  TripDuration_s  600\nset  TurquoisePatches  TRUE\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1701
2101
1855
2134
Apply!
set HabitatsInput ChooseHabitatsInput
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
1701
2056
1856
2101
ChooseHabitatsInput
ChooseHabitatsInput
"none" "BS-Habitats_Suss.csv"
1

@#$#@#$#@
# Terms of use of the software BEESCOUT

Bumble-BEESCOUT is a landscape module for the models BEEHAVE and Bumble-BEEHAVE.

BEESCOUT, BEEHAVE and Bumble-BEEHAVE can be downloaded for free from http://beehave-model.net/.

Publications:
Becher, M. A., Grimm, V., Thorbek, P., Horn, J., Kennedy, P. J., & Osborne, J. L. (2014) BEEHAVE: a systems model of honeybee colony dynamics and foraging to explore multifactorial causes of colony failure. _Journal of Applied Ecology_, 51, 470-482.

Becher, MA, Grimm, V, Knapp, J, Horn, J, Osborne, JL (2016) BEESCOUT: a software tool to characterise nectar/pollen landscapes and model bee scouting behaviour for BEEHAVE. _Ecological Modelling_ 340 (2016): 126-133.


Becher, MA, Twiston-Davies, G, Penny, TD, Goulson, D, Rotheray, EL, Osborne, JL (2018) Bumble-BEEHAVE: a systems model for exploring multifactorial causes of bumblebee decline at individual, colony, population and community level. _Journal of Applied Ecology_.



## Copyright and Licence Information:
Copyright 2015, 2017, 2018 by Matthias Becher and the University of Exeter

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

A copy of the GNU General Public License can be found at http://www.gnu.org/licenses/gpl.html or write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.



## Recommendations when using BEEHAVE and BEESCOUT:

• Please refer to the BEEHAVE/BEESCOUT publication (Becher et al. 2014; Becher et al. 2016) and the BEEHAVE website (http://beehave-model.net/) when using BEEHAVE/BEESCOUT.

• We recommend that any publication or report based on using BEEHAVE or BEESCOUT shall include, in the Supplementary Material, the very NetLogo file that was used to produce the corresponding figure, table, or other kinds of results, as well as the "Experiments" in the BehaviorSpace and all necessary input files (see Supplementary Material of Becher et al. 2014 as example). If you changed the code, we recommend to document these changes in all detail and to provide a revised ODD model description in which the modified or added elements are highlighted.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

bee_mb_1
true
0
Circle -7500403 true true 110 75 80
Circle -7500403 true true 101 157 98
Circle -6459832 true false 107 124 86
Line -7500403 true 150 100 105 60
Line -7500403 true 150 100 195 60
Circle -7500403 true true 103 178 92
Circle -7500403 true true 117 227 62
Polygon -7500403 true true 120 150 60 225 60 240 75 255 105 255 120 240 135 165 120 150
Polygon -7500403 true true 180 150 240 225 240 240 225 255 195 255 180 240 165 165 180 150
Circle -16777216 true false 116 88 19
Circle -16777216 true false 163 86 19
Circle -16777216 true false 112 99 19
Circle -16777216 true false 168 97 19

beehive1
false
3
Rectangle -6459832 true true 15 135 285 270
Rectangle -7500403 true false 0 105 300 135
Line -16777216 false 15 240 285 240
Rectangle -16777216 true false 120 240 180 255

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
